@@ -7,10 +7,7 @@ Align::Align( QWidget* parent, int anz, int ein)
     : QDialog( parent, "al", true, 0 )
 {
     Anzahl = anz;
-    if (Anzahl > 2)
-    	setCaption( tr( "Distribute/Align" ) );
-    else
-    	setCaption( tr( "Align" ) );
+		Anzahl > 2 ? setCaption(tr("Distribute/Align")) : setCaption(tr("Align"));
   	setIcon(loadIcon("AppIcon.xpm"));
     AlignLayout = new QVBoxLayout( this );
     AlignLayout->setSpacing( 0 );
@@ -28,11 +25,11 @@ Align::Align( QWidget* parent, int anz, int ein)
     ButtonGroup1Layout->setSpacing( 5 );
     ButtonGroup1Layout->setMargin( 10 );
     TextLabel1 = new QLabel( ButtonGroup1, "TextLabel1" );
-    TextLabel1->setEnabled( TRUE );
+    TextLabel1->setEnabled( true );
     TextLabel1->setText( tr( "between:" ) );
     ButtonGroup1Layout->addWidget( TextLabel1, 0, 0 );
     VartH = new QComboBox( true, ButtonGroup1, "VartH" );
-    VartH->setEnabled( TRUE );
+    VartH->setEnabled( true );
     VartH->setMinimumSize( QSize( 100, 22 ) );
     VartH->insertItem(tr("Left Sides"));
     VartH->insertItem(tr("Middles"));
@@ -51,7 +48,7 @@ Align::Align( QWidget* parent, int anz, int ein)
     TextLabelD->setEnabled(false);
     ButtonGroup1Layout->addWidget( TextLabelD, 3, 1);
     AHor = new MSpinBox( ButtonGroup1, 2 );
-    AHor->setEnabled( TRUE );
+    AHor->setEnabled( true );
     AHor->setMinimumSize( QSize( 80, 20 ) );
     AHor->setMaxValue( 100000 );
     AHor->setMinValue( -100000 );
@@ -59,7 +56,7 @@ Align::Align( QWidget* parent, int anz, int ein)
     AHor->setEnabled(false);
     ButtonGroup1Layout->addWidget( AHor, 3, 2, Qt::AlignRight);
     VerteilenH = new QRadioButton( ButtonGroup1, "VerteilenH" );
-    VerteilenH->setEnabled( TRUE );
+    VerteilenH->setEnabled( true );
     VerteilenH->setText( tr( "Distribute evenly" ) );
     if (Anzahl < 3)
     	VerteilenH->setEnabled(false);
@@ -76,11 +73,11 @@ Align::Align( QWidget* parent, int anz, int ein)
     ButtonGroup1_2Layout->setSpacing( 5 );
     ButtonGroup1_2Layout->setMargin( 10 );
     TextLabel1_2 = new QLabel( ButtonGroup1_2, "TextLabel1" );
-    TextLabel1_2->setEnabled( TRUE );
+    TextLabel1_2->setEnabled( true );
     TextLabel1_2->setText( tr( "between:" ) );
     ButtonGroup1_2Layout->addWidget( TextLabel1_2, 0, 0 );
     VartV = new QComboBox( true, ButtonGroup1_2, "VartH" );
-    VartV->setEnabled( TRUE );
+    VartV->setEnabled( true );
     VartV->setMinimumSize( QSize( 100, 22 ) );
     VartV->insertItem(tr("Top Sides"));
     VartV->insertItem(tr("Middles"));
@@ -99,7 +96,7 @@ Align::Align( QWidget* parent, int anz, int ein)
     TextLabelD2->setEnabled(false);
     ButtonGroup1_2Layout->addWidget( TextLabelD2, 3, 1 );
     AVert = new MSpinBox( ButtonGroup1_2, 2 );
-    AVert->setEnabled( TRUE );
+    AVert->setEnabled( true );
     AVert->setMinimumSize( QSize( 80, 20 ) );
 		switch (ein)
 			{
@@ -142,7 +139,7 @@ Align::Align( QWidget* parent, int anz, int ein)
     Layout3->addItem( spacer );
     OKbutton = new QPushButton( this, "OKbutton" );
     OKbutton->setText( tr( "OK" ) );
-    OKbutton->setDefault( TRUE );
+    OKbutton->setDefault( true );
     Layout3->addWidget( OKbutton );
     QSpacerItem* spacer_2 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
     Layout3->addItem( spacer_2 );
@@ -165,8 +162,6 @@ Align::Align( QWidget* parent, int anz, int ein)
 		connect(ButtonApply, SIGNAL(clicked()), this, SLOT( slotApplyDiag()));
     connect( ButtonGroup1, SIGNAL( clicked(int) ), this, SLOT( DistHoriz() ) );
     connect( ButtonGroup1_2, SIGNAL( clicked(int) ), this, SLOT( DistVert() ) );
-		connect(AHor, SIGNAL(valueChanged(int)), this, SLOT(setVa()));
-		connect(AVert, SIGNAL(valueChanged(int)), this, SLOT(setVa()));
 }
 
 /*  
@@ -177,29 +172,6 @@ Align::~Align()
     // no need to delete child widgets, Qt does it all for us
 }
 
-void Align::setVa()
-{
-	setFocus();
-}
-
-void Align::keyPressEvent(QKeyEvent *k)
-{
-	if (k->key() == Key_Shift)
-		{
-    AHor->setLineStep(10);
-    AVert->setLineStep(10);
-		}
-}
-
-void Align::keyReleaseEvent(QKeyEvent *k)
-{
-	if (k->key() == Key_Shift)
-		{
-    AHor->setLineStep(100);
-    AVert->setLineStep(100);
-		}
-}
-
 void Align::DistHoriz()
 {
     if (CheckH->isChecked())
@@ -230,9 +202,9 @@ void Align::DistVert()
 
 void Align::slotApplyDiag()
 {
-	float xdp = float(AHor->value()) / UmReFaktor / 100.0;
+	float xdp = static_cast<float>(AHor->value()) / UmReFaktor / 100.0;
 	bool xa = (CheckH->isChecked() || VerteilenH->isChecked());
-	float ydp = float(AVert->value()) / UmReFaktor / 100.0;
+	float ydp = static_cast<float>(AVert->value()) / UmReFaktor / 100.0;
 	bool ya = (CheckV->isChecked() || VerteilenV->isChecked());
 	int xart = VartH->currentItem();
 	int yart = VartV->currentItem();
