@@ -1,7 +1,6 @@
 #ifndef ALIGN_H
 #define ALIGN_H
 
-#include <qvariant.h>
 #include <qdialog.h>
 #include <qlayout.h>
 #include <qbuttongroup.h>
@@ -42,7 +41,6 @@ public:
     int Anzahl;
 
 public slots:
-		virtual void setVa();
     virtual void DistHoriz();
     virtual void DistVert();
     virtual void slotApplyDiag();
@@ -51,8 +49,6 @@ signals:
 		void ApplyDist(bool, bool, bool, bool, float, float, int, int);
 
 protected:
-		void keyPressEvent(QKeyEvent *k);
-		void keyReleaseEvent(QKeyEvent *k);
     QVBoxLayout* AlignLayout;
     QHBoxLayout* Layout4;
     QGridLayout* ButtonGroup1Layout;
