@@ -18,17 +18,11 @@
 #include "cmykcolor.h"
 #include "config.h"
 #ifdef HAVE_CMS
-	#include <lcms.h>
-extern cmsHPROFILE CMSinputProf;
-extern cmsHPROFILE CMSoutputProf;
-extern cmsHPROFILE CMSprinterProf;
+#include <lcms.h>
 extern cmsHTRANSFORM stdTrans;
 extern cmsHTRANSFORM stdProof;
 extern bool SoftProofing;
-extern bool Gamut;
 extern bool CMSuse;
-extern int IntentMonitor;
-extern int IntentPrinter;
 #endif
 
 CMYKColor::CMYKColor(int c, int m, int y, int k)
@@ -37,10 +31,6 @@ CMYKColor::CMYKColor(int c, int m, int y, int k)
 	Spot = false;
 }
 
-CMYKColor::~CMYKColor()
-{
-}
-
 void CMYKColor::setColor(int c, int m, int y, int k)
 {
 	C = c;
@@ -75,6 +65,13 @@ QColor CMYKColor::getRGBColor()
 	return RGB;
 }
 
+void CMYKColor::getRawRGBColor(int *r, int *g, int *b)
+{
+	*r = 255-QMIN(255, C+K);
+	*g = 255-QMIN(255,M+K);
+	*b = 255-QMIN(255,Y+K);
+}
+
 void CMYKColor::getCMYK(int *c, int *m, int *y, int *k)
 {
 	*c = C;
