@@ -19,13 +19,14 @@
 #include "customfdialog.moc"
 #include <qimage.h>
 #include <qpixmap.h>
+#include <qpainter.h>
 #include <qfileinfo.h>
 #include <qdir.h>
 #include <qdom.h>
-
 extern QImage LoadPict(QString fn);
 extern bool loadTextQS(QString nam, QString *Buffer);
 extern QPixmap loadIcon(QString nam);
+extern QString DocDir;
 
 ImIconProvider::ImIconProvider(QWidget *pa) : QFileIconProvider(pa)
 {
@@ -36,6 +37,12 @@ ImIconProvider::ImIconProvider(QWidget *pa) : QFileIconProvider(pa)
   fmts += "jpg";
   fmts += "xpm";
   fmts += "tif";
+  fmts += "bmp";
+  fmts += "pbm";
+  fmts += "pgm";
+  fmts += "ppm";
+  fmts += "xbm";
+  fmts += "xpm";
   imagepm = loadIcon("image.png");
   pspm = loadIcon("postscript.png");
   txtpm = loadIcon("txt.png");
@@ -43,13 +50,9 @@ ImIconProvider::ImIconProvider(QWidget *pa) : QFileIconProvider(pa)
   pdfpm = loadIcon("pdf.png");
 }
 
-ImIconProvider::~ImIconProvider()
-{
-}
-
 const QPixmap * ImIconProvider::pixmap(const QFileInfo &fi)
 {
-	QString ext = fi.extension().lower();
+	QString ext = fi.extension(false).lower();
 	if (fmts.contains(ext))
    	{
 		return &imagepm;
@@ -62,6 +65,8 @@ const QPixmap * ImIconProvider::pixmap(const QFileInfo &fi)
 			return &txtpm;
 		if (ext == "scd")
 			return &docpm;
+		if (ext == "sla")
+			return &docpm;
 		if (ext == "pdf")
 			return &pdfpm;
 		return QFileIconProvider::pixmap(fi);
@@ -72,41 +77,48 @@ FDialogPreview::FDialogPreview(QWidget *pa) : QLabel(pa)
 {
 	setAlignment(AlignLeft | AlignTop);
 	setMinimumSize( QSize( 100, 100 ) );
-	setScaledContents( FALSE );
+	setScaledContents( false );
 	setEraseColor( white );
 	setFrameShape( QLabel::WinPanel );
 	setFrameShadow( QLabel::Sunken );
 }
 
-FDialogPreview::~FDialogPreview()
-{
-}
-
 void FDialogPreview::GenPreview(QString name)
 {
 	QPixmap pm;
 	QString Buffer = "";
 	setText("");
 	QFileInfo fi = QFileInfo(name);
-	QString ex = fi.extension(false).lower();
-	if ((ex == "eps") || (ex == "jpg") || (ex == "gif") || (ex == "xpm") || (ex == "png") || (ex == "tif"))
+	QString ex = fi.extension(false).upper();
+	QStrList imfo = QImageIO::inputFormats();
+	if (ex == "JPG")
+		ex = "JPEG";
+	if ((imfo.contains(ex))||(ex=="PS")||(ex=="EPS")||(ex=="TIF"))
 		{
 		QImage im = LoadPict(name);
 		if (!im.isNull())
 			{
-			if ((im.width() > width()-5) || (im.height() > height()-5))
+			int ix = im.width();
+			int iy = im.height();
+			QString tmp = "";
+			if ((im.width() > width()-5) || (im.height() > height()-20))
 				{
 				QImage im2;
-				float sx = im.width() / float(width()-5);
-				float sy = im.height() / float(height()-5);
-				if (sy < sx)
-					im2 = im.smoothScale(im.width() / sx, im.height() / sx);
-				else
-					im2 = im.smoothScale(im.width() / sy, im.height() / sy);
+				float sx = im.width() / 
+				  static_cast<float>(width()-5);
+				float sy = im.height() / 
+				  static_cast<float>(height()-20);
+				im2 = sy < sx ?  im.smoothScale(qRound(im.width() / sx), qRound(im.height() / sx)) : im.smoothScale(qRound(im.width() / sy), qRound(im.height() / sy));
 				im = im2;
 				im2.detach();
 				}
-			pm.convertFromImage(im);
+			QPainter p;
+			pm = QPixmap(width(), height());
+			pm.fill(white);
+			p.begin(&pm);
+			p.drawImage(0, 0, im);
+			p.drawText(2, height()-5, tr("Size:")+" "+tmp.setNum(ix)+" x "+tmp.setNum(iy));
+			p.end();
 			setPixmap(pm);
 			}
 		}
@@ -149,16 +161,15 @@ void FDialogPreview::previewUrl( const QUrl &url )
 }
 
 CustomFDialog::CustomFDialog(QWidget *pa, QString cap, QString filter, bool Pre, bool mod, bool comp)
-						 : QFileDialog(pa, "FD", true)
+						 : QFileDialog(QString::null, filter, pa, 0, true)
 {
  	setIcon(loadIcon("AppIcon.xpm"));
  	setCaption(cap);
-	setFilters(filter);
 	cDir = QDir();
 	setDir(cDir);
 	setIconProvider(new ImIconProvider(this));
-	FDialogPreview *pw = new FDialogPreview( this );
 	setContentsPreviewEnabled( true );
+	FDialogPreview *pw = new FDialogPreview( this );
 	setContentsPreview( pw, pw );
 	if (comp)
 		{
@@ -173,10 +184,10 @@ CustomFDialog::CustomFDialog(QWidget *pa, QString cap, QString filter, bool Pre,
   	Layout1->addItem( spacer );
 		}
 	if (mod)
-		setMode(ExistingFiles);
+		setMode(QFileDialog::ExistingFile);
 	else
 		{
-		setMode(AnyFile);
+		setMode(QFileDialog::AnyFile);
 		if (comp)
 			addWidgets(0, Layout, 0);
 		}
@@ -187,6 +198,11 @@ CustomFDialog::CustomFDialog(QWidget *pa, QString cap, QString filter, bool Pre,
 	setViewMode( QFileDialog::List );
 	if (comp)
 		connect(SaveZip, SIGNAL(clicked()), this, SLOT(HandleComp()));
+	HomeB = new QToolButton(this);
+	HomeB->setIconSet(loadIcon("gohome.png"));
+	HomeB->setTextLabel(tr("Moves to your Document Directory.\nThis can be set in the Preferences."));
+	connect(HomeB, SIGNAL(clicked()), this, SLOT(slotHome()));
+	addToolButton(HomeB);
 }
 
 CustomFDialog::~CustomFDialog()
@@ -195,6 +211,11 @@ CustomFDialog::~CustomFDialog()
 	cDir.setCurrent(dir()->path());
 }
 
+void CustomFDialog::slotHome()
+{
+	setDir(QDir(DocDir));
+}
+
 void CustomFDialog::HandleComp()
 {
 	QString tmp;
