@@ -26,6 +26,7 @@
 #include <qcheckbox.h>
 #include <qlayout.h>
 #include <qframe.h>
+#include <qtoolbutton.h>
 /**
   *@author Franz Schmid
   */
@@ -41,7 +42,7 @@ class ImIconProvider : public QFileIconProvider
 
 public:
     ImIconProvider(QWidget *pa);
-    ~ImIconProvider();
+    ~ImIconProvider() {};
 
     const QPixmap * pixmap(const QFileInfo &fi);
 };
@@ -51,9 +52,9 @@ class FDialogPreview : public QLabel, public QFilePreview
     Q_OBJECT
 public:
 	FDialogPreview(QWidget *pa);
-	~FDialogPreview();
+	~FDialogPreview() {};
 	void GenPreview(QString name);
-	void previewUrl(const QUrl &url);
+	virtual void previewUrl(const QUrl &url);
 };
 
 class CustomFDialog : public QFileDialog
@@ -65,7 +66,9 @@ public:
 	QDir cDir;
 	QCheckBox* SaveZip;
 	QFrame* Layout;
+	QToolButton* HomeB;
 private slots:
+	void slotHome();
 	void HandleComp();
 protected:
 	QHBoxLayout* Layout1;
