@@ -1,7 +1,6 @@
 #ifndef EDITSTYLE_H
 #define EDITSTYLE_H
 
-#include <qvariant.h>
 #include <qdialog.h>
 #include <qbuttongroup.h>
 #include <qlabel.h>
@@ -11,7 +10,6 @@
 #include <qspinbox.h>
 #include <qlayout.h>
 #include <qtooltip.h>
-#include <qwhatsthis.h>
 #include <qcombobox.h>
 #include "mspinbox.h"
 #include "scribusdoc.h"
@@ -21,10 +19,8 @@ class EditStyle : public QDialog
     Q_OBJECT
 
 public:
-    EditStyle( QWidget* parent, struct StVorL *vor, QValueList<StVorL> v, bool neu);
-    ~EditStyle();
-    void keyPressEvent(QKeyEvent *k);
-    void keyReleaseEvent(QKeyEvent *k);
+    EditStyle( QWidget* parent, struct StVorL *vor, QValueList<StVorL> v, bool neu, SCFonts *avail, float au);
+    ~EditStyle() {};
 
     QLabel* TextLabel1;
     QLabel* TextLabel1_2;
@@ -46,15 +42,22 @@ public:
     QRadioButton* Right;
     QRadioButton* Full;
     QRadioButton* Forced;
+    QGroupBox* GroupFont;
+    QLabel* TextF1;
+    QComboBox* FontC;
+    QSpinBox* SizeC;
+    QLabel* TextF2;
     QPushButton* Cancel;
     QPushButton* OkButton;
     struct StVorL *werte;
     QValueList<StVorL> allV;
     QString OldName;
     bool IsNew;
+		float AutoVal;
 
 private slots:
 		void Verlassen();
+		void FontChange(int val);
 
 protected:
     QHBoxLayout* Layout17;
@@ -62,6 +65,7 @@ protected:
     QGridLayout* GroupBox10Layout;
     QGridLayout* ButtonGroup1Layout;
     QGridLayout* AbstandVLayout;
+    QGridLayout* GroupFontLayout;
 };
 
 #endif // EDITSTYLE_H
