@@ -1,13 +1,11 @@
 #ifndef STILFORMATE_H
 #define STILFORMATE_H
 
-#include <qvariant.h>
 #include <qdialog.h>
 #include <qlistbox.h>
 #include <qpushbutton.h>
 #include <qlayout.h>
 #include <qtooltip.h>
-#include <qwhatsthis.h>
 #include "scribusdoc.h"
 
 class StilFormate : public QDialog
@@ -15,8 +13,8 @@ class StilFormate : public QDialog
     Q_OBJECT
 
 public:
-    StilFormate( QWidget* parent, ScribusDoc *doc);
-    ~StilFormate();
+    StilFormate( QWidget* parent, ScribusDoc *doc, SCFonts *avail);
+    ~StilFormate() {};
 
     QListBox* ListBox1;
     QPushButton* NewB;
@@ -27,6 +25,8 @@ public:
     QPushButton* CancelB;
     int sFnumber;
   	QValueList<StVorL> TempVorl;
+    SCFonts *fon;
+		ScribusDoc *Docu;
   	void UpdateFList();
 
 public slots:
