@@ -17,14 +17,13 @@
 
 #include "fmitem.h"
 #include <qfontmetrics.h>
+#include <qapplication.h>
 
 FmItem::FmItem(const QString& s, const QFont& f)
 {
 	string = s;
 	font = f;
-}
-FmItem::~FmItem()
-{
+	font.setPointSize(qApp->font().pointSize());
 }
 
 void FmItem::paint(QPainter *p, const QColorGroup&, bool, bool, int x, int y, int w, int h)
