@@ -30,7 +30,7 @@
 class FmItem : public QCustomMenuItem {
 public: 
 	FmItem(const QString& s, const QFont& f);
-	~FmItem();
+	~FmItem() {};
 	void paint(QPainter *p, const QColorGroup& cg, bool act, bool enabled, int x, int y, int w, int h);
 	QSize sizeHint();
 private:
