@@ -19,7 +19,7 @@ NodePalette::NodePalette( QWidget* parent)
     ButtonGroup1->setFrameShape( QButtonGroup::NoFrame );
     ButtonGroup1->setFrameShadow( QButtonGroup::Plain );
     ButtonGroup1->setTitle( tr( "" ) );
-    ButtonGroup1->setExclusive( TRUE );
+    ButtonGroup1->setExclusive( true );
     ButtonGroup1->setColumnLayout(0, Qt::Vertical );
     ButtonGroup1->layout()->setSpacing( 0 );
     ButtonGroup1->layout()->setMargin( 0 );
@@ -31,23 +31,23 @@ NodePalette::NodePalette( QWidget* parent)
     MoveNode = new QToolButton( ButtonGroup1, "MoveNode" );
     MoveNode->setText( tr( "" ) );
     MoveNode->setPixmap(loadIcon("MoveNode.png"));
-    MoveNode->setToggleButton( TRUE );
+    MoveNode->setToggleButton( true );
 		MoveNode->setOn(true);
     ButtonGroup1Layout->addWidget( MoveNode );
     MoveControl = new QToolButton( ButtonGroup1, "MoveControl" );
     MoveControl->setText( tr( "" ) );
     MoveControl->setPixmap(loadIcon("MoveKontrol.png"));
-    MoveControl->setToggleButton( TRUE );
+    MoveControl->setToggleButton( true );
     ButtonGroup1Layout->addWidget( MoveControl );
     AddNode = new QToolButton( ButtonGroup1, "AddNode" );
     AddNode->setText( tr( "" ) );
     AddNode->setPixmap(loadIcon("AddNode.png"));
-    AddNode->setToggleButton( TRUE );
+    AddNode->setToggleButton( true );
     ButtonGroup1Layout->addWidget( AddNode );
     DeleteNode = new QToolButton( ButtonGroup1, "DeleteNode" );
     DeleteNode->setText( tr( "" ) );
     DeleteNode->setPixmap(loadIcon("DeleteNode.png"));
-    DeleteNode->setToggleButton( TRUE );
+    DeleteNode->setToggleButton( true );
     ButtonGroup1Layout->addWidget( DeleteNode );
     NodePaletteLayout->addWidget( ButtonGroup1 );
 
@@ -55,31 +55,31 @@ NodePalette::NodePalette( QWidget* parent)
     ButtonGroup2->setFrameShape( QButtonGroup::NoFrame );
     ButtonGroup2->setFrameShadow( QButtonGroup::Plain );
     ButtonGroup2->setTitle( tr( "" ) );
-    ButtonGroup2->setExclusive( TRUE );
+    ButtonGroup2->setExclusive( true );
     ButtonGroup2->setColumnLayout(0, Qt::Vertical );
     ButtonGroup2->layout()->setSpacing( 2 );
     ButtonGroup2->layout()->setMargin( 0 );
     ButtonGroup2Layout = new QHBoxLayout( ButtonGroup2->layout() );
     ButtonGroup2Layout->setAlignment( Qt::AlignTop );
     AsymMove = new QToolButton( ButtonGroup2, "AsymMove" );
-    AsymMove->setEnabled( FALSE );
+    AsymMove->setEnabled( false );
     AsymMove->setText( tr( "" ) );
     AsymMove->setPixmap(loadIcon("MoveAsym.png"));
-    AsymMove->setToggleButton( TRUE );
+    AsymMove->setToggleButton( true );
     ButtonGroup2Layout->addWidget( AsymMove );
     SymMove = new QToolButton( ButtonGroup2, "SymMove" );
-    SymMove->setEnabled( FALSE );
+    SymMove->setEnabled( false );
     SymMove->setText( tr( "" ) );
     SymMove->setPixmap(loadIcon("MoveSym.png"));
-    SymMove->setToggleButton( TRUE );
+    SymMove->setToggleButton( true );
     ButtonGroup2Layout->addWidget( SymMove );
     ResNode = new QToolButton( ButtonGroup2, "resnode" );
-    ResNode->setEnabled( FALSE );
+    ResNode->setEnabled( false );
     ResNode->setText( tr( "" ) );
     ResNode->setPixmap(loadIcon("ResetNode.png"));
     ButtonGroup2Layout->addWidget( ResNode );
     Res1Node = new QToolButton( ButtonGroup2, "res1node" );
-    Res1Node->setEnabled( FALSE );
+    Res1Node->setEnabled( false );
     Res1Node->setText( tr( "" ) );
     Res1Node->setPixmap(loadIcon("Reset1Node.png"));
     ButtonGroup2Layout->addWidget( Res1Node );
@@ -89,20 +89,20 @@ NodePalette::NodePalette( QWidget* parent)
     ButtonGroup3->setFrameShape( QButtonGroup::NoFrame );
     ButtonGroup3->setFrameShadow( QButtonGroup::Plain );
     ButtonGroup3->setTitle( tr( "" ) );
-    ButtonGroup3->setExclusive( TRUE );
+    ButtonGroup3->setExclusive( true );
     ButtonGroup3->setColumnLayout(0, Qt::Vertical );
     ButtonGroup3->layout()->setSpacing( 2 );
     ButtonGroup3->layout()->setMargin( 0 );
     ButtonGroup3Layout = new QHBoxLayout( ButtonGroup3->layout() );
     ButtonGroup3Layout->setAlignment( Qt::AlignTop );
     PolySplit = new QToolButton( ButtonGroup3, "PolySplit" );
-    PolySplit->setEnabled( FALSE );
+    PolySplit->setEnabled( false );
     PolySplit->setText( tr( "" ) );
-    PolySplit->setToggleButton( TRUE );
+    PolySplit->setToggleButton( true );
     PolySplit->setPixmap(loadIcon("PolyCut.png"));
     ButtonGroup3Layout->addWidget( PolySplit );
     BezierClose = new QToolButton( ButtonGroup3, "BezierClose" );
-    BezierClose->setEnabled( FALSE );
+    BezierClose->setEnabled( false );
     BezierClose->setText( tr( "" ) );
     BezierClose->setPixmap(loadIcon("BezierClose.png"));
     ButtonGroup3Layout->addWidget( BezierClose );
@@ -159,33 +159,6 @@ NodePalette::NodePalette( QWidget* parent)
 		connect(YSpin, SIGNAL(valueChanged(int)), this, SLOT(MovePoint()));
 }
 
-NodePalette::~NodePalette()
-{
-}
-
-void NodePalette::setVa()
-{
-	setFocus();
-}
-
-void NodePalette::keyPressEvent(QKeyEvent *k)
-{
-	if (k->key() == Key_Shift)
-		{
-    XSpin->setLineStep(10);
-    YSpin->setLineStep(10);
-		}
-}
-
-void NodePalette::keyReleaseEvent(QKeyEvent *k)
-{
-	if (k->key() == Key_Shift)
-		{
-    XSpin->setLineStep(100);
-    YSpin->setLineStep(100);
-		}
-}
-
 void NodePalette::setDoc(ScribusDoc *dc)
 {
 	doc = dc;
@@ -370,8 +343,8 @@ void NodePalette::DelN()
 void NodePalette::closeEvent(QCloseEvent *)
 {
 	MoveN();
-  PolySplit->setEnabled( FALSE );
-  BezierClose->setEnabled( FALSE );
+  PolySplit->setEnabled( false );
+  BezierClose->setEnabled( false );
 	doc->ActPage->ClRe = -1;
 	emit Schliessen();
 }
@@ -379,8 +352,8 @@ void NodePalette::closeEvent(QCloseEvent *)
 void NodePalette::EndEdit()
 {
 	MoveN();
-  PolySplit->setEnabled( FALSE );
-  BezierClose->setEnabled( FALSE );
+  PolySplit->setEnabled( false );
+  BezierClose->setEnabled( false );
 	doc->ActPage->ClRe = -1;
 	emit Schliessen();
 }
