@@ -17,6 +17,8 @@
 
 #include "hruler.h"
 #include "hruler.moc"
+#include "page.h"
+#include <qcursor.h>
 Hruler::Hruler(QScrollView *pa, ScribusDoc *doc) : QWidget(pa)
 {
 	setEraseColor(QColor(255,255,255));
@@ -25,10 +27,28 @@ Hruler::Hruler(QScrollView *pa, ScribusDoc *doc) : QWidget(pa)
 	rfont.setPointSize(9);
 	offs = -10;
 	Markp = 0;
-	repX = FALSE;
+	repX = false;
+	Mpressed = false;
 }
 
-Hruler::~Hruler(){
+void Hruler::mousePressEvent(QMouseEvent *)
+{
+	Mpressed = true;
+	qApp->setOverrideCursor(QCursor(SplitHCursor), true);
+}
+
+void Hruler::mouseReleaseEvent(QMouseEvent *m)
+{
+	Mpressed = false;
+	doku->ActPage->DrHY = -1;
+	doku->ActPage->SetYGuide(m);
+	qApp->setOverrideCursor(QCursor(ArrowCursor), true);
+}
+
+void Hruler::mouseMoveEvent(QMouseEvent *m)
+{
+	if ((Mpressed) && (m->pos().y() > height()))
+		doku->ActPage->FromHRuler(m);
 }
 
 void Hruler::paintEvent(QPaintEvent *)
@@ -67,41 +87,38 @@ void Hruler::paintEvent(QPaintEvent *)
 		cr.setPoints(3, Markp, 9, Markp+2, 0, Markp-2, 0);
 		p.drawPolygon(cr);
 		p.end();
-		repX = FALSE;
+		repX = false;
 		return;
 		}
 	p.setBrush(black);
 	p.setPen(black);
 	p.setFont(rfont);
 	p.scale(sc, 1.0);
-	if ((doku->PageFP) && (doku->PagesSbS))
-		pc = 2;
-	else
-		pc = 1;
+	((doku->PageFP) && (doku->PagesSbS)) ? pc = 2 : pc = 1;
 	if (doku->MasterP)
 		pc = 1;
-	for (xx = 0; xx < pc; xx++)
+	for (xx = 0; xx < pc; ++xx)
 		{
 		of = xx * (doku->PageB+30.0);
 		for (xl = 0; xl < doku->PageB; xl += iter)
 			{
-			p.drawLine(xl+of, 18, xl+of, 24);
+			p.drawLine(static_cast<int>(xl+of), 18, static_cast<int>(xl+of), 24);
 			}
 		for (xl = 0; xl < doku->PageB+(iter2/2); xl += iter2)
 			{
-			p.drawLine(xl+of, 11, xl+of, 24);
+			p.drawLine(static_cast<int>(xl+of), 11, static_cast<int>(xl+of), 24);
 			p.save();
 			p.scale(1.0 / sc, 1.0);
 			switch (doku->Einheit)
 				{
 				case 2:
-					p.drawText((xl+of+qRound(2/sc)) * sc, 17, QString::number(xl / iter2));
+					p.drawText(static_cast<int>((xl+of+qRound(2/sc)) * sc), 17, QString::number(xl / iter2));
 					break;
 				case 3:
-					p.drawText((xl+of+qRound(2/sc)) * sc, 17, QString::number(xl / iter));
+					p.drawText(static_cast<int>((xl+of+qRound(2/sc)) * sc), 17, QString::number(xl / iter));
 					break;
 				default:
-					p.drawText((xl+of+qRound(2/sc)) * sc, 17, QString::number(xl / iter * 10));
+					p.drawText(static_cast<int>((xl+of+qRound(2/sc)) * sc), 17, QString::number(xl / iter * 10));
 					break;
 				}
 			p.restore();
@@ -112,7 +129,7 @@ void Hruler::paintEvent(QPaintEvent *)
 /** Zeichnet den Pfeil */
 void Hruler::Draw(int wo)
 {
-	repX = TRUE;
+	repX = true;
 	Markp = wo-qRound(10*doku->Scale);
 	repaint(QRect(0, 0, width(), 9));
 }
