@@ -23,12 +23,12 @@ About::About( QWidget* parent )
     TabWidget2 = new QTabWidget( this, "TabWidget2" );
     TabWidget2->setMinimumSize( QSize( 438, 258 ) );
     tab = new QWidget( TabWidget2, "tab" );
+    tabLayout1 = new QHBoxLayout( tab );
+    tabLayout1->setSpacing( 6 );
+    tabLayout1->setMargin( 10 );
     PixmapLabel1 = new QLabel( tab, "PixmapLabel1" );
-    PixmapLabel1->setGeometry( QRect( 10, 10, 414, 209 ) );
     PixmapLabel1->setPixmap(loadIcon("scribus_logo.jpg"));
-    PixmapLabel1->setMinimumSize( QSize( 414, 209 ) );
-    PixmapLabel1->setScaledContents(true);
-    PixmapLabel1->setAlignment( int( QLabel::AlignTop | QLabel::AlignLeft ) );
+    tabLayout1->addWidget( PixmapLabel1 );
     TabWidget2->insertTab( tab, tr( "About" ) );
     tab_2 = new QWidget( TabWidget2, "tab_2" );
     tabLayout = new QHBoxLayout( tab_2 );
@@ -41,11 +41,12 @@ About::About( QWidget* parent )
                         "<tr><td><b>" + tr("Contributions from:") + "</b></td><td></td></tr>" +
                         "<tr><td>Christian Tpp</td><td>mr-ct@gmx.de</td></tr>" +
                         "<tr><td>Alastair Robinson</td><td>blackfive@fakenhamweb.co.uk</td></tr>" +
+                        "<tr><td>Paul Johnson</td><td>paulf.johnson@ukonline.co.uk</td></tr>" +
                         "<tr><td></td><td> </td></tr>" +
                         "<tr><td><b>" + tr("Documentation:") + "</b></td><td></td></tr>" +
-                        "<tr><td>Thomas Zastrow</td><td>webmaster@thomas-zastrow.de</td></tr>" +
+                        "<tr><td>Peter Linnell</td><td>scribusdocs@atlantictechsolutions.com</td></tr>" +
                         "<tr><td>Yves Ceccone</td><td>yves@yeccoe.org</td></tr>" +
-                        "<tr><td>Peter Linnell</td><td>netscribe@attbi.com</td></tr></table>");
+                        "<tr><td>Thomas Zastrow</td><td>webmaster@thomas-zastrow.de</td></tr></table>");
     TextView1->setTextFormat( QTextView::RichText );
     tabLayout->addWidget( TextView1 );
     TabWidget2->insertTab( tab_2, tr( "Authors" ) );
@@ -60,9 +61,10 @@ About::About( QWidget* parent )
                         "<tr><td><b>" + tr("French:") + "</b></td><td> </td>" +
                         "<tr><td>Michel Briand</td><td>michelbriand@free.fr</td></tr>" +
                         "<tr><td>Yves Ceccone</td><td>yves@yeccoe.org</td></tr>" +
+                        "<tr><td>Nicolas Boos</td><td>nicolas.boos@wanadoo.fr</td></tr>" +
                         "<tr><td> </td><td> </td></tr>" +
                         "<tr><td><b>" + tr("Spanish and Catalan:") + "</b></td><td> </td></tr>" +
-                        "<tr><td>Josep Febrer</td><td>jfebrer@linuxcorel.f2s.com</td></tr>" +
+                        "<tr><td>Josep Febrer</td><td>josep@linuxmail.org</td></tr>" +
                         "<tr><td> </td><td> </td></tr>" +
                         "<tr><td><b>" + tr("Hungarian and Italian:") + "</b></td><td> </td></tr>" +
                         "<tr><td>Giovanni Bicz</td><td>gbiczo@freestart.hu</td></tr>" +
@@ -82,8 +84,17 @@ About::About( QWidget* parent )
                         "<tr><td><b>" + tr("Lithuanian:") + "</b></td><td> </td></tr>" +
                         "<tr><td>Aivaras Kirejevas</td><td>kiras@mail.lt</td></tr>" +
                         "<tr><td> </td><td> </td></tr>" +
+                        "<tr><td><b>" + tr("Polish:") + "</b></td><td> </td></tr>" +
+                        "<tr><td>Maciej Haski</td><td>m.hanski@gmx.at</td></tr>" +
+                        "<tr><td> </td><td> </td></tr>" +
                         "<tr><td><b>" + tr("Slovak:") + "</b></td><td></td></tr>" +
-                        "<tr><td>Zdenko Podobn</td><td>zdpo@mailbox.sk</td></tr></table>");
+                        "<tr><td>Zdenko Podobn</td><td>zdpo@mailbox.sk</td></tr>" +
+                        "<tr><td> </td><td> </td></tr>" +
+                        "<tr><td><b>" + tr("Danish:") + "</b></td><td></td></tr>" +
+                        "<tr><td>Morten Langlo</td><td>mlanglo@post6.tele.dk</td></tr>" +
+                        "<tr><td> </td><td> </td></tr>" +
+                        "<tr><td><b>" + tr("English:") + "</b></td><td></td></tr>" +
+                        "<tr><td>Paul F. Johnson</td><td>paulf.johnson@ukonline.co.uk</td></tr></table>");
     TextView2->setTextFormat( QTextView::RichText );
     tabLayout_2->addWidget( TextView2 );
     TabWidget2->insertTab( tab_3, tr( "Translations" ) );
@@ -95,8 +106,7 @@ About::About( QWidget* parent )
     Layout2->addItem( spacer );
     PushButton1 = new QPushButton( this, "PushButton1" );
     PushButton1->setText( tr( "Close" ) );
-    PushButton1->setMinimumSize( QSize( 121, 32 ) );
-    PushButton1->setDefault( TRUE );
+    PushButton1->setDefault( true );
     Layout2->addWidget( PushButton1 );
     AboutLayout->addLayout( Layout2 );
     setMaximumSize(sizeHint());
