@@ -1,7 +1,6 @@
 #ifndef ABOUT_H
 #define ABOUT_H
 
-#include <qvariant.h>
 #include <qdialog.h>
 #include <qlabel.h>
 #include <qtabwidget.h>
@@ -30,6 +29,7 @@ public:
 protected:
     QVBoxLayout* AboutLayout;
     QHBoxLayout* tabLayout;
+    QHBoxLayout* tabLayout1;
     QHBoxLayout* tabLayout_2;
     QHBoxLayout* Layout2;
 
