@@ -20,6 +20,7 @@
 #include <qstring.h>
 #include <qcstring.h>
 #include <qpen.h>
+#include <qfile.h>
 #include "scribusdoc.h"
 
 /**
@@ -31,8 +32,10 @@ class PSLib {
 public:
 	PSLib(bool psart, SCFonts &AllFonts, QMap<QString,QFont> DocFonts, CListe DocColors, bool pdf = false);
 	virtual ~PSLib();
+	virtual bool PS_set_file(QString fn);
 	virtual void PS_set_Info(QString art, QString was);
-	virtual void PS_begin_page(int ori, float breite, float hoehe, struct Margs* Ma);
+	virtual void PS_begin_doc(int Ori, float breite, float hoehe, int numpage);
+	virtual void PS_begin_page(float breite, float hoehe, struct Margs* Ma);
 	virtual void PS_end_page();
 	virtual void PS_rect(float x, float y, float b, float h);
 	virtual void PS_RoundRect(float x, float y, float b, float h, float r);
@@ -48,6 +51,7 @@ public:
 	virtual void PS_save();
 	virtual void PS_restore();
 	virtual void PS_setcmykcolor_fill(float c, float m, float y, float k);
+	virtual void PS_setcmykcolor_dummy();
 	virtual void PS_setcmykcolor_stroke(float c, float m, float y, float k);
 	virtual void PS_setlinewidth(float w);
 	virtual void PS_setdash(Qt::PenStyle st, Qt::PenCapStyle ca, Qt::PenJoinStyle jo);
@@ -56,23 +60,34 @@ public:
 	virtual void PS_fill();
 	virtual void PS_stroke();
 	virtual void PS_fill_stroke();
+	virtual void PS_newpath();
+	virtual void PS_GradientCol1(float c, float m, float y, float k);
+	virtual void PS_GradientCol2(float c, float m, float y, float k);
+	virtual void PS_LinGradient(float w, float h, int item, int grad);
+	virtual void PS_RadGradient(float w, float h, int item);
 	virtual void PS_underline(QCString ch, float x, float y);
 	virtual void PS_strikeout(QCString ch, float x, float y);
 	virtual void PS_show_xy(QCString ch, float x, float y);
-	virtual void PS_show();
+	virtual void PS_show(float x, float y);
 	virtual void PS_show_xyBold(QCString ch, float x, float y);
-	virtual void PS_image(float x, float y, QString fn, float scalex, float scaley);
+	virtual void PS_image(float x, float y, QString fn, float scalex, float scaley, QString Name = "");
 	virtual void PS_plate(int nr);
 	virtual void PS_setGray();
 	virtual void PDF_Bookmark(QString text, uint Seite);
 	virtual void PDF_Annotation(QString text, float x, float y, float b, float h);
-	virtual QString PS_close();
+	virtual void PS_close();
+	virtual void PS_TemplateStart(QString Name, float breite, float hoehe);
+	virtual void PS_TemplateEnd();
+	virtual void PS_UseTemplate(QString Name);
+	virtual void PS_ImageData(QString fn, QString Name);
 private:
 	void PutSeite(QString c);
 	void PutDoc(QString c);
 	QString ToStr(float c);
 	QString IToStr(int c);
-	char *toHex( uchar u );
+//	char *toHex( uchar u );
+//	QString String2Hex(QString *in);
+	QString PSEncode(QString in);
 	bool Art;
 	QString Prolog;
 	QString Header;
@@ -87,16 +102,19 @@ private:
 	QString GrayCalc;
 	bool GraySc;
 	int Seiten;
-	QString Dokument;
-	QString Seite;
 	QString FillColor;
 	QString StrokeColor;
+	QString GrColor1;
+	QString GrColor2;
 	float LineW;
 	QString Fonts;
 	QString FontDesc;
 	QMap<QString, QString> UsedFonts;
-	SCFonts FontDef;
 	bool isPDF;
+	QFile Spool;
+	bool CompAvail;
+	int Plate;
+	bool DoSep;
 };
 
 #endif
