@@ -28,7 +28,7 @@
 class LineCombo : public QComboBox  {
 public: 
 	LineCombo(QWidget* pa);
-	~LineCombo();
+	~LineCombo() {};
 };
 
 #endif
