@@ -7,7 +7,6 @@
 #include <qlayout.h>
 #include <qvariant.h>
 #include <qtooltip.h>
-#include <qwhatsthis.h>
 extern QPixmap loadIcon(QString nam);
 extern float UmReFaktor;
 
@@ -73,7 +72,7 @@ Mdup::Mdup( QWidget* parent, float Dx, float Dy, int Ein )
     Layout3->setMargin( 0 );
     PushButton12 = new QPushButton( this, "PushButton12" );
     PushButton12->setText( tr( "OK" ) );
-    PushButton12->setDefault( TRUE );
+    PushButton12->setDefault( true );
     Layout3->addWidget( PushButton12 );
     QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
     Layout3->addItem( spacer );
@@ -86,38 +85,6 @@ Mdup::Mdup( QWidget* parent, float Dx, float Dy, int Ein )
     // signals and slots connections
     connect( PushButton12, SIGNAL( clicked() ), this, SLOT( accept() ) );
     connect( PushButton13, SIGNAL( clicked() ), this, SLOT( reject() ) );
-		connect(ShiftH, SIGNAL(valueChanged(int)), this, SLOT(setVa()));
-		connect(ShiftV, SIGNAL(valueChanged(int)), this, SLOT(setVa()));
 }
 
-/*  
- *  Destroys the object and frees any allocated resources
- */
-Mdup::~Mdup()
-{
-    // no need to delete child widgets, Qt does it all for us
-}
-
-void Mdup::setVa()
-{
-	setFocus();
-}
-
-void Mdup::keyPressEvent(QKeyEvent *k)
-{
-	if (k->key() == Key_Shift)
-		{
-    ShiftH->setLineStep(10);
-    ShiftV->setLineStep(10);
-		}
-}
-
-void Mdup::keyReleaseEvent(QKeyEvent *k)
-{
-	if (k->key() == Key_Shift)
-		{
-    ShiftH->setLineStep(100);
-    ShiftV->setLineStep(100);
-		}
-}
 
