@@ -81,7 +81,7 @@ DmF::DmF( QWidget* parent, QString fon, SCFonts &avail )
     PixmapLabel1->setMinimumSize( QSize( 50, 50 ) );
     PixmapLabel1->setMaximumSize( QSize( 50, 50 ) );
     PixmapLabel1->setPixmap( image0 );
-    PixmapLabel1->setScaledContents( TRUE );
+    PixmapLabel1->setScaledContents( true );
     Layout1->addWidget( PixmapLabel1, 1, 0 );
     TextLabel4 = new QLabel( this, "TextLabel4" );
     TextLabel4->setText( tr( "Use" ) );
@@ -94,7 +94,8 @@ DmF::DmF( QWidget* parent, QString fon, SCFonts &avail )
     SCFontsIterator it(avail);
     for ( ; it.current(); ++it)
     	{
-    	rlist.append(it.currentKey());
+			if (it.current()->UseFont)
+    		rlist.append(it.currentKey());
     	}
 		rlist.sort();
 		Replace->insertStringList(rlist);
@@ -113,13 +114,6 @@ DmF::DmF( QWidget* parent, QString fon, SCFonts &avail )
     connect( PushButton1, SIGNAL( clicked() ), this, SLOT( accept() ) );
 }
 
-/*  
- *  Destroys the object and frees any allocated resources
- */
-DmF::~DmF()
-{
-    // no need to delete child widgets, Qt does it all for us
-}
 
 void DmF::NeuerFont(const QString& e)
 {
