@@ -1,7 +1,7 @@
 #include "muster.h"
 #include "muster.moc"
 #include "newtemp.h"
-#include <qmsgbox.h>
+#include <qmessagebox.h>
 
 extern QPixmap loadIcon(QString nam);
 
@@ -25,17 +25,14 @@ MusterSeiten::MusterSeiten( QWidget* parent, ScribusDoc *doc, ScribusView *view,
     Layout2->setMargin( 0 );
 
     NewB = new QPushButton( this, "NewB" );
-    NewB->setMinimumSize( QSize( 100, 30 ) );
     NewB->setText( tr( "New" ) );
     Layout2->addWidget( NewB );
 
     DuplicateB = new QPushButton( this, "DublicateB" );
-    DuplicateB->setMinimumSize( QSize( 100, 30 ) );
     DuplicateB->setText( tr( "Duplicate" ) );
     Layout2->addWidget( DuplicateB );
 
     DeleteB = new QPushButton( this, "DeleteB" );
-    DeleteB->setMinimumSize( QSize( 100, 30 ) );
     DeleteB->setText( tr( "Delete" ) );
     Layout2->addWidget( DeleteB );
 
@@ -43,7 +40,6 @@ MusterSeiten::MusterSeiten( QWidget* parent, ScribusDoc *doc, ScribusView *view,
     Layout2->addItem( spacer );
 
     ExitB = new QPushButton( this, "ExitB" );
-    ExitB->setMinimumSize( QSize( 100, 30 ) );
     ExitB->setText( tr( "Exit" ) );
     Layout2->addWidget( ExitB );
     MusterSeitenLayout->addLayout( Layout2 );
@@ -69,24 +65,29 @@ MusterSeiten::MusterSeiten( QWidget* parent, ScribusDoc *doc, ScribusView *view,
     connect(ListBox1, SIGNAL(highlighted(QListBoxItem*)), this, SLOT(selTemplate(QListBoxItem*)));
 }
 
-/*  
+/*<<<<<<< muster.cpp
+void MusterSeiten::closeEvent(QCloseEvent *)
+=======
+*  
  *  Destroys the object and frees any allocated resources
- */
+ *
+*
 MusterSeiten::~MusterSeiten()
 {
-    // no need to delete child widgets, Qt does it all for us
-}
+     no need to delete child widgets, Qt does it all for us
+}*/
 
-void MusterSeiten::closeEvent(QCloseEvent *)
+void MusterSeiten::closeEvent(QCloseEvent *ce)
+  //>>>>>>> 1.3
 {
-	ExitEditor();
+	View->HideTemplate();
+	emit Fertig();
+	ce->accept();
 }
 
 void MusterSeiten::ExitEditor()
 {
-	View->HideTemplate();
-	emit Fertig();
-	accept();
+	close();
 }
 
 void MusterSeiten::DelTemp()
@@ -105,11 +106,11 @@ void MusterSeiten::DelTemp()
 		View->delPage(View->MasterNames[sMuster]);
 		View->reformPages();
 		View->MasterNames.clear();
-		for (uint a=0; a<View->Pages.count(); a++)
+		for (uint a=0; a<View->Pages.count(); ++a)
 			{
 			View->MasterNames[View->Pages.at(a)->PageNam] = View->Pages.at(a)->PageNr;
 			}
-		for (uint b=0; b<View->DocPages.count(); b++)
+		for (uint b=0; b<View->DocPages.count(); ++b)
 			{
 			if (View->DocPages.at(b)->MPageNam == sMuster)
 				View->DocPages.at(b)->MPageNam = "Normal";
@@ -143,7 +144,7 @@ void MusterSeiten::DuplTemp()
     		}
     	nr = View->Pages.count();
     	View->MasterNames.insert(nam, nr);
-			for (uint a=0; a<View->Pages.count(); a++)
+			for (uint a=0; a<View->Pages.count(); ++a)
 				{
 				View->Pages.at(a)->parentWidget()->hide();
 				}
@@ -153,18 +154,15 @@ void MusterSeiten::DuplTemp()
 			emit CreateNew(nr);
 			if (Doc->PageFP)
 				{
-				if (dia->Links->currentItem() == 0)
-					View->Pages.at(nr)->LeftPg = true;
-				else
-					View->Pages.at(nr)->LeftPg = false;
+				  View->Pages.at(nr)->LeftPg = dia->Links->currentItem() == 0 ? true : false;
 				}
 			int inde = View->MasterNames[sMuster];
-			for (uint a=0; a<View->Pages.at(inde)->Items.count(); a++)
+			for (uint a=0; a<View->Pages.at(inde)->Items.count(); ++a)
 				{
 				View->Pages.at(inde)->Items.at(a)->CopyIt(&Buffer);
 				Doc->ActPage->PasteItem(&Buffer, true);
 				}
-			Doc->ActPage->Deselect();
+			Doc->ActPage->Deselect(true);
 			View->DrawNew();
 			View->Pages.at(nr)->PageNam = nam;
 			View->Pages.at(nr)->MPageNam = "";
@@ -196,7 +194,7 @@ void MusterSeiten::NewTemp()
     		}
     	nr = View->Pages.count();
     	View->MasterNames.insert(nam, nr);
-			for (uint a=0; a<View->Pages.count(); a++)
+			for (uint a=0; a<View->Pages.count(); ++a)
 				{
 				View->Pages.at(a)->parentWidget()->hide();
 				}
@@ -206,10 +204,7 @@ void MusterSeiten::NewTemp()
 			emit CreateNew(nr);
 			if (Doc->PageFP)
 				{
-				if (dia->Links->currentItem() == 0)
-					View->Pages.at(nr)->LeftPg = true;
-				else
-					View->Pages.at(nr)->LeftPg = false;
+				  View->Pages.at(nr)->LeftPg = dia->Links->currentItem() == 0 ? true : false;
 				}
 			View->Pages.at(nr)->PageNam = nam;
 			View->Pages.at(nr)->MPageNam = "";
