@@ -1,7 +1,6 @@
 #ifndef NEWDOC_H
 #define NEWDOC_H
 
-#include <qvariant.h>
 #include <qdialog.h>
 #include <qbuttongroup.h>
 #include <qcheckbox.h>
@@ -13,7 +12,6 @@
 #include <qspinbox.h>
 #include <qlayout.h>
 #include <qtooltip.h>
-#include <qwhatsthis.h>
 #include "mspinbox.h"
 #include "scribusdoc.h"
 
@@ -23,7 +21,7 @@ class NewDoc : public QDialog
 
 public:
     NewDoc( QWidget* parent, preV *Vor );
-    ~NewDoc();
+    ~NewDoc() {};
 
     QButtonGroup* ButtonGroup1_2;
     QGroupBox* GroupBox7;
@@ -72,7 +70,6 @@ public:
     void setSize(int gr);
 
 public slots:
-		void setVa();
 		void setTop(int v);
 		void setBottom(int v);
 		void setLeft(int v);
@@ -86,8 +83,6 @@ public slots:
     void setAT();
 
 protected:
-		void keyPressEvent(QKeyEvent *k);
-		void keyReleaseEvent(QKeyEvent *k);
     QGridLayout* Layout4;
     QGridLayout* Layout3;
     QHBoxLayout* NewDocLayout;
