@@ -37,7 +37,7 @@ Q_OBJECT
 
 public:
 	Page(QWidget *pa, int x, int y, int b, int h, ScribusDoc *doc, QScrollView *view);
-	~Page();
+	~Page() {};
   /** Zeichnet eine Ellipse */
   int PaintEllipse(float x, float y, float b, float h, float w, QString fill, QString outline);
   /** Zeichnet eine Bildbox */
@@ -51,12 +51,13 @@ public:
 	/** Zeichnet ein Polygon */
 	int PaintPoly(float x, float y, float b, float h, float w, QString fill, QString outline);
 	int PaintPolyLine(float x, float y, float b, float h, float w, QString fill, QString outline);
-  /** Ldt ein Bild */
+  /** Laedt ein Bild */
   void LoadPict(QString fn, int ItNr);
   void insertColor(QString nam, float c, float m, float y, float k);
   void DrawPageMarks(QPaintEvent *e);
   void DrawPageItems(QPaintEvent *e);
 	void paintEvent(QPaintEvent *e);
+	void DrawTransparent(PageItem *b);
 	void setGroupRect();
 	void getGroupRect(float *x, float *y, float *w, float *h);
 	void getGroupRectScreen(float *x, float *y, float *w, float *h);
@@ -77,7 +78,7 @@ public:
 	void dropEvent(QDropEvent *e);
 	bool SeleItem(QMouseEvent *m);
 	bool SeleItemPos(QPoint m);
-	void Deselect();
+	void Deselect(bool prop = true);
 	void SelectItemNr(int nr);
 	void SetupDraw(int Nr);
 	void MoveItemI(float newX, float newY, int ite);
@@ -101,22 +102,30 @@ public:
 	void MoveRotated(PageItem *b, FPoint npv);
 	void AdjustPictScale(PageItem *b);
 	bool SizeItem(float newX, float newY, int ite, bool fromMP = false, bool DoUpdateClip = true);
-	bool MoveSizeItem(QPoint newX, QPoint newY, int ite);
+	bool MoveSizeItem(FPoint newX, FPoint newY, int ite);
 	void RotateItem(float win, int ite);
 	void MarkClip(PageItem *b);
 	void Transform(PageItem *b, QPainter *p);
 	void TransformM(PageItem *b, QPainter *p);
 	void PaintSizeRect(QPainter *p, QRect alt, QRect neu);
 	QPoint ApplyGrid(QPoint in);
-	FPoint Page::ApplyGridF(FPoint in);
+	FPoint ApplyGridF(FPoint in);
 	void RefreshItem(PageItem *b);
 	void RepaintTextRegion(PageItem *b, QRegion alt);
 	void DrawCursChar(PageItem *b, QPainter *p, int po);
 	void EmitValues(PageItem *b);
+	void AdjustPreview(PageItem *b);
+	void UpdateGradient(PageItem *i);
+	void FromHRuler(QMouseEvent *m);
+	void FromVRuler(QMouseEvent *m);
+	void SetYGuide(QMouseEvent *m);
+	void SetXGuide(QMouseEvent *m);
+	void SnapToGuides(PageItem* b);
+	void ApplyGuides(float *x, float *y);
 	QRegion ViewReg();
   /** Liste der Elemente */
   QPtrList<PageItem> Items;
-  /** Dokument zu dem die Seite gehrt */
+  /** Dokument zu dem die Seite gehoert */
   ScribusDoc *doku;
   /** Nummer der Seite */
   uint PageNr;
@@ -157,6 +166,15 @@ public:
 	float GroupW;
 	float GroupH;
 	bool HanMove;
+	int DrHY;
+	int DrVX;
+	QValueList<float> XGuides;
+	QValueList<float> YGuides;
+	uint GyM;
+	bool MoveGY;
+	uint GxM;
+	bool MoveGX;
+	FPoint RCenter;
 
 public slots:
 	void ChLineWidth(float w);
@@ -167,15 +185,17 @@ public slots:
 	void ChLocalSc(float x, float y);
 	void ToggleBookmark();
 	void ToggleAnnotation();
+	void ToggleLock();
 	void TogglePic();
 	void FlipImageH();
 	void FlipImageV();
 	void ItemFont(QString fon);
 	void chFSize(int size);
 	void ItemPen(QString farbe);
-	void ItemBrush(QString farbe);
+	void ItemBrush(QString farbe, bool vCPal = false);
 	void ItemPenShade(int sha);
-	void ItemBrushShade(int sha);
+	void ItemBrushShade(int sha, bool vCPal = false);
+	void ItemGradFill(int typ, QString col1, int sh1, QString col2, int sh2);
 	void QueryFarben();
 	void SetFrameRect();
 	void SetFrameRounded();
@@ -214,13 +234,13 @@ signals: // Signals
   void PgCh(int);
   /** Element gezeichnet */
   void PaintingDone();
-  /** Element ausgewhlt */
+  /** Element ausgewaehlt */
   void HaveSel(int);
-  /** Seite verndert */
+  /** Seite veraendert */
   void DocChanged();
   /** Position eines Elementes */
   void ItemPos(float, float);
-  /** Breite und Hhe eines Elementes */
+  /** Breite und Hoehe eines Elementes */
   void ItemGeom(float, float);
   void ItemRadius(float);
   /** Setzt den Drehungswinkel des Elementes */
@@ -231,19 +251,20 @@ signals: // Signals
   void ZoomAbs();
   void AbsPosi(int, int);
   void AbsPosi2(int, int);
-  /** Sendet die Linienstrke an die Mapalette */
+  /** Sendet die Linienstaerke an die Masspalette */
   void SetSizeValue(float);
-  /** Sendet die Linienart an die Mapalette */
+  /** Sendet die Linienart an die Masspalette */
   void SetLineArt(PenStyle, PenCapStyle, PenJoinStyle);
-  /** Sendet die lokalen Bildeigenschaften an die Mapalette */
+  /** Sendet die lokalen Bildeigenschaften an die Masspalette */
   void SetLocalValues(float, float, float, float);
   /** Sendet die Stiftfarbe an die Farbpalette */
   void ItemFarben(QString, QString, int, int);
-  /** Sendet die Textattribute an die Mapalette */
+  void ItemGradient(QString, QString, int, int, int);
+  /** Sendet die Textattribute an die Masspalette */
   void ItemTextAttr(float);
   /** Sendet die Schriftart */
   void ItemTextFont(QString);
-  /** Sendet die Schriftgre */
+  /** Sendet die Schriftgroesse */
   void ItemTextSize(int);
   void ItemTextUSval(float);
   void ItemTextAbs(int);
@@ -255,7 +276,7 @@ signals: // Signals
   void ItemTextStil(int);
   void LoadPic();
   void ModifyIt();
-  void LoadElem(QString, int, int, bool, bool);
+  void LoadElem(QString, int, int, bool, bool, ScribusDoc *);
   void Amode(int);
 	void AnnotProps();
 	void ToScrap(QString);
@@ -265,6 +286,13 @@ signals: // Signals
 	void PolyOpen();
 	void PStatus(int, uint);
 	void UndoAvail();
+	void EditGuides();
+	void ItemTrans(float);
+	void AddBM(PageItem *);
+	void DelBM(PageItem *);
+	void NewBMNr(int, int);
+	void ChBMText(PageItem *);
+	void RotMode(int);
 };
 
 #endif
