@@ -1,13 +1,11 @@
 #ifndef PICSTATUS_H
 #define PICSTATUS_H
 
-#include <qvariant.h>
 #include <qdialog.h>
 #include <qpushbutton.h>
 #include <qtable.h>
 #include <qlayout.h>
 #include <qtooltip.h>
-#include <qwhatsthis.h>
 #include <qcheckbox.h>
 #include <qheader.h>
 #include <qptrlist.h>
@@ -21,7 +19,7 @@ class PicStatus : public QDialog
 
 public:
     PicStatus(QWidget* parent, ScribusDoc *docu, ScribusView *viewi);
-    ~PicStatus();
+    ~PicStatus() {};
 
     QTable* PicTable;
     QHeader *Header;
