@@ -35,7 +35,7 @@ class Foi
 {
 	public:
 		Foi(QString scname, QString path, bool embedps, SCFonts_Encoding &encoding);
-		virtual ~Foi();
+		virtual ~Foi() {};
 		virtual QString RealName();
 		virtual bool EmbedFont(QString &str);
 		virtual bool ReadMetrics();
@@ -56,6 +56,7 @@ class Foi
 		QString FontEnc;
 		bool IsFixedPitch;
 		QString FontBBox;
+		bool UseFont;
 };
 
 
@@ -76,11 +77,12 @@ class SCFonts : public QDict<Foi>
 			setAutoDelete(true);
 		}
 		~SCFonts();
-		void GetFonts();
+		void GetFonts(QString pf);
+		void FreeExtraFonts();
 	private:
 		void AddPath(QString p);
 		void AddScalableFonts(const QString &path);
-		void AddUserPath();
+		void AddUserPath(QString pf);
 		void AddXFontServerPath();
 		void AddXFontPath();
 		QStrList FontPath;
