@@ -3,11 +3,11 @@
 #include <qfile.h>
 #include <qfileinfo.h>
 #include <qstring.h>
-#include <qvector.h>
-#include <qarray.h>
+#include <qptrvector.h>
+#include <qmemarray.h>
 #include <qregexp.h>
 
-#include <iostream.h>
+#include <iostream>
 #include <sys/types.h>
 
 #include "scfonts_ttf.h"
@@ -29,6 +29,8 @@ QString showTag(u_int32_t tag)
 
 enum sc_TTFontError {sc_TTFOK,sc_TTFNoFile,sc_TTFFileError,sc_TTFNoMemory,sc_TTFBadFile};
 
+using namespace std;
+
 class sc_TTFont
 {
 	public:
@@ -43,7 +45,7 @@ class sc_TTFont
 			for(int i=0;i<nGlyphs;++i)
 			{
 				if(OwnEncoding.present(i))
-					cout << i << " -> " << OwnEncoding[i] << endl;
+					std::cout << i << " -> " << OwnEncoding[i] << endl;
 			}
 		}
 		void MapEncoding()
@@ -55,7 +57,7 @@ class sc_TTFont
 					QString &glyph=Encoding[i];
 					if(OwnEncoding.present(glyph))
 					{
-						cout << i << ": " << glyph << " -> " << OwnEncoding[glyph] << endl;
+						std::cout << i << ": " << glyph << " -> " << OwnEncoding[glyph] << endl;
 					}
 				}
 			}
@@ -555,7 +557,7 @@ bool sc_TTFont::readPostTable()
 			}
 			u_int16_t nglyphsps = readBEUInt16();
 			if(nglyphsps!=nGlyphs)
-				cout << "Warning: nGlyphs should be consistent between head and post" << endl;
+				std::cout << "Warning: nGlyphs should be consistent between head and post" << endl;
 
 #ifdef doPost
 			GlyphNames.resize(nglyphsps);
@@ -752,7 +754,7 @@ bool sc_TTFont::readCmapTable()
 
 	if((windozeOffset<0) && (macOffset>0))
 	{
-		cout << "Using Mac encoding table" << endl;
+		std::cout << "Using Mac encoding table" << endl;
 		return(false);
 #if 0		// Need to implement Mac encoding sometime...
 struct CmapFormat0
@@ -832,9 +834,9 @@ struct CmapFormat0
 #if 0
 		for(int i=0;i<segCount;++i)
 		{
-			cout << i << endl;
-			cout << "  " << tcm.startCount[i] << " - " << tcm.endCount[i] << endl;
-			cout << "  " << tcm.idDelta[i] << " : " << tcm.idRangeOffset[i] << endl;
+			std::cout << i << endl;
+			std::cout << "  " << tcm.startCount[i] << " - " << tcm.endCount[i] << endl;
+			std::cout << "  " << tcm.idDelta[i] << " : " << tcm.idRangeOffset[i] << endl;
 		}
 #endif
 
@@ -1064,11 +1066,11 @@ bool sc_TTFont::Type42Metrics(QString *fb, QString *as, QString *ds, QString *it
 		Head.xMax*1000L/Head.unitsPerEm,
 		Head.yMax*1000L/Head.unitsPerEm);
 		*fb = tmp;
-		*as = tmp.setNum(int(Hhea.Ascender*1000L/Head.unitsPerEm));
-		*ds = tmp.setNum(int(Hhea.Descender*1000L/Head.unitsPerEm));
+		*as = tmp.setNum(static_cast<int>(Hhea.Ascender*1000L/Head.unitsPerEm));
+		*ds = tmp.setNum(static_cast<int>(Hhea.Descender*1000L/Head.unitsPerEm));
 		tmp.sprintf("%d.%d",Post.italicAngle.mantissa,Post.italicAngle.fraction);
 		*it = tmp;
-		*fp = int(Post.isFixedPitch);
+		*fp = static_cast<int>(Post.isFixedPitch);
 		return true;
 }
 
