@@ -33,6 +33,7 @@
 #include "cmykcolor.h"
 #include "scfonts.h"
 #include "fpointarray.h"
+#include "hyphenator.h"
 #ifdef HAVE_CMS
 	#include <lcms.h>
 #endif
@@ -40,7 +41,7 @@
 class PageItem;
 class Page;
 
-/* Struktur fr Pageitem Text */
+/* Struktur fuer Pageitem Text */
 struct Pti { QString ch;
 				     float xp;
 				     float yp;
@@ -70,6 +71,11 @@ struct CLBuf { int PType;
 							 QString Pcolor2;
 							 int Shade;
 							 int Shade2;
+							 QString GrColor;
+							 QString GrColor2;
+							 int GrShade;
+							 int GrShade2;
+							 int GrType;
 							 float Rot;
 							 int PLineArt;
 							 int PLineJoin;
@@ -87,6 +93,7 @@ struct CLBuf { int PType;
 							 float BBoxH;
 							 bool isPrintable;
 							 bool isBookmark;
+							 int BMnr;
 							 bool isAnnotation;
 							 int AnType;
 							 QString AnAction;
@@ -122,6 +129,9 @@ struct CLBuf { int PType;
 							 int AnIPlace;
 							 int AnScaleW;
 							 float Extra;
+							 float TExtra;
+							 float BExtra;
+							 float RExtra;
 							 QString Pfile;
 							 QString Pfile2;
 							 QString Pfile3;
@@ -142,9 +152,11 @@ struct CLBuf { int PType;
 							 int LayerNr;
 							 bool ScaleType;
 							 bool AspectRatio;
+							 bool Locked;
+							 float Transparency;
 							};
 
-  /** Seitenrnder */
+  /** Seitenraender */
 struct Margs { float Top;
            		 float Left;
            		 float Right;
@@ -158,6 +170,8 @@ struct StVorL { QString Vname;
 								float First;
 								float Avor;
 								float Anach;
+								QString Font;
+								int FontSize;
 							};
 
 struct CMSset {
@@ -165,6 +179,8 @@ struct CMSset {
   						QString DefaultPrinterProfile;
   						QString DefaultInputProfile;
   						QString DefaultInputProfile2;
+							int ComponentsInput2;
+							int ComponentsPrinter;
   						int DefaultIntentMonitor;
   						int DefaultIntentMonitor2;
   						int DefaultIntentPrinter;
@@ -220,6 +236,26 @@ struct PDFOpt { bool Thumbnails;
 								QValueList<QString> EmbedList;
 								bool PresentMode;
 								QValueList<PreSet> PresentVals;
+								QString Datei;
+								bool UseRGB;
+								bool UseProfiles;
+								bool UseProfiles2;
+								QString SolidProf;
+								int SComp;
+								QString ImageProf;
+								bool EmbeddedI;
+								int Intent2;
+								QString PrintProf;
+								QString Info;
+								int Intent;
+								float BleedTop;
+								float BleedLeft;
+								float BleedRight;
+								float BleedBottom;
+								bool Encrypt;
+								QString PassOwner;
+								QString PassUser;
+								int Permissions;
 							};
 							
 struct Keys { QString Name;
@@ -234,12 +270,14 @@ struct preV  { SCFonts AvailFonts;
 							 int Wheelval;
 							 int AppFontSize;
 							 int GrabRad;
+							 float GuideRad;
 							 float DminGrid;
 							 float DmajGrid;
 							 QColor DminColor;
 							 QColor DmajColor;
 							 QColor DpapColor;
 							 QColor DmargColor;
+							 QColor guideColor;
 							 QString GUI;
 							 int DVHoch;
 							 int DVHochSc;
@@ -270,15 +308,9 @@ struct preV  { SCFonts AvailFonts;
 							 bool Mpalv;
 							 int Mpalx;
 							 int Mpaly;
-							 bool Cpalv;
-							 int Cpalx;
-							 int Cpaly;
 							 bool Tpalv;
 							 int Tpalx;
 							 int Tpaly;
-							 bool Spalv;
-							 int Spalx;
-							 int Spaly;
 							 int Npalx;
 							 int Npaly;
 							 int MainX;
@@ -296,6 +328,9 @@ struct preV  { SCFonts AvailFonts;
 							 bool Sepalv;
 							 int Sepalx;
 							 int Sepaly;
+							 bool Bopalv;
+							 int Bopalx;
+							 int Bopaly;
 							 bool SepalT;
 							 bool SepalN;
 							 int PSize;
@@ -328,6 +363,13 @@ struct preV  { SCFonts AvailFonts;
 							 bool ErsteLinks;
 							 bool ScaleType;
 							 bool AspectRatio;
+							 int MinWordLen;
+							 QString Language;
+							 bool Automatic;
+							 bool AutoCheck;
+							 QString DocDir;
+							 QMap<QString,QString> GFontSub;
+							 bool PDFTransparency;
 						 };
 /**
   * the Document Class
@@ -338,7 +380,7 @@ class ScribusDoc : public QObject
 
 public:
     ScribusDoc();
-    ~ScribusDoc();
+    ~ScribusDoc() {};
     void setModified();
     void setUnModified();
     bool isModified() const;
@@ -349,40 +391,44 @@ public:
   protected:
     bool modified;
 	public: // Public attributes
-  /** Vergrerungsfaktor fr das Dokument */
+  /** Vergroesserungsfaktor fuer das Dokument */
   float Scale;
   bool Marks;
+	bool Guides;
+	bool SnapGuides;
+	float GuideRad;
+	bool GuideLock;
   bool loading;
   /** Breite der Seite  */
   float PageB;
-  /** Hhe der Seite */
+  /** Hoehe der Seite */
   float PageH;
   /** Anzahl der Seiten */
   int PageC;
-  /** Seitenrnder */
+  /** Seitenraender */
   Margs PageM;
   /** Anzahl der Spalten */
   float PageSp;
   /** Abstand der Spalten */
   float PageSpa;
-  /** Flag fr AutoTextrahmen */
+  /** Flag fuer AutoTextrahmen */
   bool PageAT;
-  /** Flag fr Doppelseiten */
+  /** Flag fuer Doppelseiten */
   bool PageFP;
-	/** Flag fr Hoch- oder Querformat 0 = Hochformat */
+	/** Flag fuer Hoch- oder Querformat 0 = Hochformat */
 	int PageOri;
 	/** Erste Seitennummer im Dokument */
 	int FirstPnum;
-  /** Flag fr Raster */
+  /** Flag fuer Raster */
   bool Raster;
-  /** Flag fr Rasterbenutzung */
+  /** Flag fuer Rasterbenutzung */
   bool useRaster;
-  /** Flag fr Bilder */
+  /** Flag fuer Bilder */
   bool ShowPic;
   /** Im Dokument benutzte Farben */
   CListe PageColors;
   Page* ActPage;
-  /** InfoStrings fr das aktuelle Dokument */
+  /** InfoStrings fuer das aktuelle Dokument */
   QString DocAutor;
   QString DocTitel;
   QString DocComments;
@@ -407,6 +453,7 @@ public:
   QColor majorColor;
   QColor papColor;
   QColor margColor;
+	QColor guideColor;
   float minorGrid;
   float majorGrid;
   int CurrentSel;
@@ -422,11 +469,11 @@ public:
   int VTief;
   /** Verkleinerung in Prozent bei Tiefstellung */
   int VTiefSc;
-  /** Verkleinerunug in Prozent bei Kapitlchen */
+  /** Verkleinerunug in Prozent bei Kapitaelchen */
   int VKapit;
-  /** Letztes Element fr AutoTextrahmen */
+  /** Letztes Element fuer AutoTextrahmen */
   PageItem *LastAuto;
-  /** Erstes Element fr AutoTextrahmen */
+  /** Erstes Element fuer AutoTextrahmen */
   PageItem *FirstAuto;
   int MagMin;
   int MagMax;
@@ -464,6 +511,31 @@ public:
 	QMap<QString,QString> JavaScripts;
 	bool UnDoValid;
 	UndoData UnData;
+	int TotalItems;
+	Hyphenator *Trenner;
+	int MinWordLen;
+	QString Language;
+	bool Automatic;
+	bool AutoCheck;
+  bool TemplateMode;
+	struct PDFOpt PDF_Optionen;
+	bool RePos;
+	struct BookMa { QString Title;
+									QString Text;
+									QString Aktion;
+									int Parent;
+									int Seite;
+									int Element;
+									int ItemNr;
+									int First;
+									int Last;
+									int Prev;
+									int Next;
+								};
+	QValueList<BookMa> BookMarks;
+	bool OldBM;
+	bool hasName;
+	int RotMode;
 };
 
 #endif
