@@ -17,7 +17,6 @@
 
 #include "scribusview.h"
 #include "scribusview.moc"
-#include "page.h"
 #include "pageback.h"
 #include <qcolor.h>
 #include <qfont.h>
@@ -28,11 +27,12 @@
 #include <qimage.h>
 #include <qcstring.h>
 extern void Level2Layer(ScribusDoc *doc, struct Layer *ll, int Level);
+extern float Cwidth(ScribusDoc *doc, QPainter *p, QString name, QString ch, int Siz);
 
 ScribusView::ScribusView(QWidget *parent, ScribusDoc *doc, preV *prefs)
  						: QScrollView(parent, "s", WRepaintNoErase | WNorthWestGravity)
 {
-	Ready = FALSE;
+	Ready = false;
 	Doc = doc;
 	Doc->PageC = 0;
   Prefs = prefs;
@@ -40,7 +40,7 @@ ScribusView::ScribusView(QWidget *parent, ScribusDoc *doc, preV *prefs)
 	setVScrollBarMode(QScrollView::AlwaysOn);
 	setMargins(25, 25, 0, 0);
 	setResizePolicy(Manual);
-	enableClipper(TRUE);
+	enableClipper(true);
   viewport()->setBackgroundMode(PaletteBackground);
 	QFont fo = QFont(font());
 	fo.setPointSize(10);
@@ -97,7 +97,7 @@ ScribusView::ScribusView(QWidget *parent, ScribusDoc *doc, preV *prefs)
 	Pages.clear();
 	MasterPages.clear();
 	DocPages.clear();
-	Ready = TRUE;
+	Ready = true;
 	connect(SB1, SIGNAL(clicked()), this, SLOT(slotZoomOut()));
 	connect(SB2, SIGNAL(clicked()), this, SLOT(slotZoomIn()));
 	connect(LE, SIGNAL(returnPressed()), this, SLOT(Zval()));
@@ -107,10 +107,6 @@ ScribusView::ScribusView(QWidget *parent, ScribusDoc *doc, preV *prefs)
 	connect(this, SIGNAL(contentsMoving(int, int)), this, SLOT(setRulerPos(int, int)));
 }
 
-ScribusView::~ScribusView()
-{
-}
-
 /** Waagrechter Scrollbalken */
 void ScribusView::setHBarGeometry(QScrollBar &bar, int x, int y, int w, int h)
 {
@@ -139,17 +135,17 @@ void ScribusView::setVBarGeometry(QScrollBar &bar, int x, int y, int w, int h)
 
 void ScribusView::setRulerPos(int x, int y)
 {
-	HR->offs = x-int(10*Doc->Scale)-2;
-	HR->repX = FALSE;
+	HR->offs = x-static_cast<int>(10*Doc->Scale)-2;
+	HR->repX = false;
 	HR->repaint();
-	VR->offs = y-int(10*Doc->Scale)-2;
+	VR->offs = y-static_cast<int>(10*Doc->Scale)-2;
 	VR->repaint();
 }
 
 void ScribusView::Zval()
 {
 	QStringList w = QStringList::split(" ", LE->text());
-	bool ok = FALSE;
+	bool ok = false;
 	QStringList::Iterator it = w.begin();
 	float s = (*it).toFloat(&ok);
 	if (ok)
@@ -166,12 +162,12 @@ Page* ScribusView::addPage(int nr)
 	int z;
 	float s = Doc->Scale;
 	QWidget* feh = new PageBack(viewport());
-	feh->resize(int((Doc->PageB+5)*s), int((Doc->PageH+5)*s));
-	Page* fe = new Page(feh, 0, 0, int(Doc->PageB*s), int(Doc->PageH*s), Doc, this);
+	feh->resize(static_cast<int>((Doc->PageB+5)*s), static_cast<int>((Doc->PageH+5)*s));
+	Page* fe = new Page(feh, 0, 0, static_cast<int>(Doc->PageB*s), static_cast<int>(Doc->PageH*s), Doc, this);
 	Doc->ActPage = fe;
 	fe->Margins.Top = Doc->PageM.Top;
 	fe->Margins.Bottom = Doc->PageM.Bottom;
-	addChild(feh, int(10*s), int(Doc->PageC*((Doc->PageH+30)*s)+10*s));
+	addChild(feh, static_cast<int>(10*s), static_cast<int>(Doc->PageC*((Doc->PageH+30)*s)+10*s));
 	feh->show();
 	Doc->PageC++;
 	Pages.insert(nr, fe);
@@ -221,7 +217,7 @@ Page* ScribusView::addPage(int nr)
 		Doc->FirstAuto->paintObj();
 		}
 	LA->setText(tr("Page")+" "+QString::number(nr+1));
-	fe->setMouseTracking(TRUE);
+	fe->setMouseTracking(true);
 	connect(fe, SIGNAL(Hrule(int)), HR, SLOT(Draw(int)));
 	connect(fe, SIGNAL(Vrule(int)), VR, SLOT(Draw(int)));
 	connect(fe, SIGNAL(PgCh(int)), this, SLOT(setMenTxt(int)));
@@ -351,7 +347,7 @@ void ScribusView::reformPages()
 		Seite->Margins.Top = Doc->PageM.Top;
 		Seite->Margins.Bottom = Doc->PageM.Bottom;
 		if (Doc->MasterP)
-			addChild(PSeite, int(10*Doc->Scale), int((Doc->PageC-1)*(PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
+			addChild(PSeite, static_cast<int>(10*Doc->Scale), static_cast<int>((Doc->PageC-1)*(PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
 		else
 			{
 			if ((Doc->PageFP) && (Prefs->PagesSbS))
@@ -359,42 +355,42 @@ void ScribusView::reformPages()
  				if (a % 2 == 0)
  					{
  					if (Doc->FirstPageLeft)
-						addChild(PSeite, int(10*Doc->Scale),
-				        	 	int(a/2 * (PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
+						addChild(PSeite, static_cast<int>(10*Doc->Scale),
+				        	 	static_cast<int>(a/2 * (PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
  					else
-						addChild(PSeite, int(PSeite->width()+35*Doc->Scale),
-				        	 	int((a+1)/2 * (PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
+						addChild(PSeite, static_cast<int>(PSeite->width()+35*Doc->Scale),
+				        	 	static_cast<int>((a+1)/2 * (PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
  					}
  				else
  					{
  					if (Doc->FirstPageLeft)
-						addChild(PSeite, int(PSeite->width()+35*Doc->Scale),
-									 	int(a/2 * (PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
+						addChild(PSeite, static_cast<int>(PSeite->width()+35*Doc->Scale),
+									 	static_cast<int>(a/2 * (PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
  					else
-						addChild(PSeite, int(10*Doc->Scale),
-									 	int((a+1)/2 * (PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
+						addChild(PSeite, static_cast<int>(10*Doc->Scale),
+									 	static_cast<int>((a+1)/2 * (PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
  					}
 				}
 			else
-				addChild(PSeite, int(10*Doc->Scale), int(a*(PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
+				addChild(PSeite, static_cast<int>(10*Doc->Scale), static_cast<int>(a*(PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
 			}
 		}
 	PSeite = Doc->ActPage->parentWidget();
 	if ((Doc->PageFP) && (Prefs->PagesSbS))
 		{
 		if (Doc->FirstPageLeft)
-			resizeContents(int(PSeite->width()*2+60*Doc->Scale),
-							 			int(((Doc->PageC-1)/2 + 1) * (PSeite->height()+25*Doc->Scale)+30));
+			resizeContents(static_cast<int>(PSeite->width()*2+60*Doc->Scale),
+							 			static_cast<int>(((Doc->PageC-1)/2 + 1) * (PSeite->height()+25*Doc->Scale)+30));
 		else
-			resizeContents(int(PSeite->width()*2+60*Doc->Scale),
-										 int((Doc->PageC/2 + 1) * (PSeite->height()+25*Doc->Scale)+30));
-		setContentsPos(childX(Doc->ActPage->parentWidget())-int(10*Doc->Scale),
-									 childY(Doc->ActPage->parentWidget())-int(10*Doc->Scale));
+			resizeContents(static_cast<int>(PSeite->width()*2+60*Doc->Scale),
+										 static_cast<int>((Doc->PageC/2 + 1) * (PSeite->height()+25*Doc->Scale)+30));
+		setContentsPos(childX(Doc->ActPage->parentWidget())-static_cast<int>(10*Doc->Scale),
+									 childY(Doc->ActPage->parentWidget())-static_cast<int>(10*Doc->Scale));
 		}
 	else
 		{
-		resizeContents(int(PSeite->width()+30*Doc->Scale), int(Doc->PageC * (PSeite->height()+25*Doc->Scale)+30));
-		setContentsPos(0, childY(Doc->ActPage->parentWidget())-int(10*Doc->Scale));
+		resizeContents(static_cast<int>(PSeite->width()+30*Doc->Scale), static_cast<int>(Doc->PageC * (PSeite->height()+25*Doc->Scale)+30));
+		setContentsPos(0, childY(Doc->ActPage->parentWidget())-static_cast<int>(10*Doc->Scale));
 		}
 	setRulerPos(contentsX(), contentsY());
  	PaMenu();
@@ -425,10 +421,10 @@ void ScribusView::slotDoZoom()
 			{
 			Seite = Pages.at(a);
 			PSeite = Seite->parentWidget();
-			Seite->resize(int(Doc->PageB*Doc->Scale), int(Doc->PageH*Doc->Scale));
-			PSeite->resize(int((Doc->PageB+5)*Doc->Scale), int((Doc->PageH+5)*Doc->Scale));
+			Seite->resize(static_cast<int>(Doc->PageB*Doc->Scale), static_cast<int>(Doc->PageH*Doc->Scale));
+			PSeite->resize(static_cast<int>((Doc->PageB+5)*Doc->Scale), static_cast<int>((Doc->PageH+5)*Doc->Scale));
 			if (Doc->MasterP)
-				addChild(PSeite, int(10*Doc->Scale), int((Doc->PageC-1)*(PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
+				addChild(PSeite, static_cast<int>(10*Doc->Scale), static_cast<int>((Doc->PageC-1)*(PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
 			else
 				{
 				if ((Doc->PageFP) && (Prefs->PagesSbS))
@@ -436,61 +432,61 @@ void ScribusView::slotDoZoom()
  					if (a % 2 == 0)
  						{
  						if (Doc->FirstPageLeft)
-							addChild(PSeite, int(10*Doc->Scale),
-				        	 		int(a/2 * (PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
+							addChild(PSeite, static_cast<int>(10*Doc->Scale),
+				        	 		static_cast<int>(a/2 * (PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
  						else
-							addChild(PSeite, int(PSeite->width()+35*Doc->Scale),
-				        	 		int((a+1)/2 * (PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
+							addChild(PSeite, static_cast<int>(PSeite->width()+35*Doc->Scale),
+				        	 		static_cast<int>((a+1)/2 * (PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
  						}
  					else
  						{
  						if (Doc->FirstPageLeft)
-							addChild(PSeite, int(PSeite->width()+35*Doc->Scale),
-									 		int(a/2 * (PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
+							addChild(PSeite, static_cast<int>(PSeite->width()+35*Doc->Scale),
+									 		static_cast<int>(a/2 * (PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
  						else
-							addChild(PSeite, int(10*Doc->Scale),
-									 		int((a+1)/2 * (PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
+							addChild(PSeite, static_cast<int>(10*Doc->Scale),
+									 		static_cast<int>((a+1)/2 * (PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
  						}
 					}
 				else
-					addChild(PSeite, int(10*Doc->Scale), int(a*(PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
+					addChild(PSeite, static_cast<int>(10*Doc->Scale), static_cast<int>(a*(PSeite->height()+25*Doc->Scale)+10*Doc->Scale));
 				}
 			}
 		if ((Doc->PageFP) && (Prefs->PagesSbS))
 			{
 			if (Doc->FirstPageLeft)
-					resizeContents(int(PSeite->width()*2+60*Doc->Scale),
-									 			int(((Doc->PageC-1)/2 + 1) * (PSeite->height()+25*Doc->Scale)+30));
+					resizeContents(static_cast<int>(PSeite->width()*2+60*Doc->Scale),
+									 			static_cast<int>(((Doc->PageC-1)/2 + 1) * (PSeite->height()+25*Doc->Scale)+30));
 			else
-				resizeContents(int(PSeite->width()*2+60*Doc->Scale),
-									 		int((Doc->PageC/2 + 1) * (PSeite->height()+25*Doc->Scale)+30));
-			setContentsPos(childX(Doc->ActPage->parentWidget())-int(10*Doc->Scale),
-									 	childY(Doc->ActPage->parentWidget())-int(10*Doc->Scale));
+				resizeContents(static_cast<int>(PSeite->width()*2+60*Doc->Scale),
+									 		static_cast<int>((Doc->PageC/2 + 1) * (PSeite->height()+25*Doc->Scale)+30));
+			setContentsPos(childX(Doc->ActPage->parentWidget())-static_cast<int>(10*Doc->Scale),
+									 	childY(Doc->ActPage->parentWidget())-static_cast<int>(10*Doc->Scale));
 			}
 		else
 			{
-			resizeContents(int(PSeite->width()+30*Doc->Scale), int(Doc->PageC * (PSeite->height()+25*Doc->Scale)+30));
-			setContentsPos(0, childY(Doc->ActPage->parentWidget())-int(10*Doc->Scale));
+			resizeContents(static_cast<int>(PSeite->width()+30*Doc->Scale), static_cast<int>(Doc->PageC * (PSeite->height()+25*Doc->Scale)+30));
+			setContentsPos(0, childY(Doc->ActPage->parentWidget())-static_cast<int>(10*Doc->Scale));
 			}
 		LE->setText(QString::number(double(Doc->Scale*100), 'f', 2)+" %");
 		setRulerPos(contentsX(), contentsY());
 		if (Doc->ActPage->SelItem.count() != 0)
 			{
 			PageItem *b = Doc->ActPage->SelItem.at(0);
-			SetCCPo(int(b->Xpos + b->Width/2), int(b->Ypos + b->Height/2));
+			SetCCPo(static_cast<int>(b->Xpos + b->Width/2), static_cast<int>(b->Ypos + b->Height/2));
 			}
 		}
 }
 
 void ScribusView::SetCCPo(int x, int y)
 {
-	center(childX(Doc->ActPage->parentWidget())+x*Doc->Scale, childY(Doc->ActPage->parentWidget())+y*Doc->Scale);
+	center(static_cast<int>(childX(Doc->ActPage->parentWidget())+x*Doc->Scale), static_cast<int>(childY(Doc->ActPage->parentWidget())+y*Doc->Scale));
 	setRulerPos(contentsX(), contentsY());	
 }
 
 void ScribusView::SetCPo(int x, int y)
 {
-	setContentsPos(childX(Doc->ActPage->parentWidget())+x*Doc->Scale, childY(Doc->ActPage->parentWidget())+y*Doc->Scale);
+	setContentsPos(static_cast<int>(childX(Doc->ActPage->parentWidget())+x*Doc->Scale), static_cast<int>(childY(Doc->ActPage->parentWidget())+y*Doc->Scale));
 	setRulerPos(contentsX(), contentsY());	
 }
 
@@ -543,7 +539,7 @@ void ScribusView::ChgUnit(int art)
 void ScribusView::GotoPage(int Seite)
 {
 	Doc->ActPage = Pages.at(Seite);
-	setContentsPos(childX(Doc->ActPage->parentWidget())-10*Doc->Scale, childY(Doc->ActPage->parentWidget())-10*Doc->Scale);
+	setContentsPos(static_cast<int>(childX(Doc->ActPage->parentWidget())-10*Doc->Scale), static_cast<int>(childY(Doc->ActPage->parentWidget())-10*Doc->Scale));
 	LA->setText(tr("Page")+" "+QString::number(Seite+1));
 }
 
@@ -552,9 +548,7 @@ void ScribusView::slotZoomIn()
 {
 	Doc->Scale *= 2;
 	if (Doc->Scale > 32)
-		{
 		Doc->Scale = 32;
-		}
 	slotDoZoom();
 }
 
@@ -568,22 +562,18 @@ void ScribusView::slotZoomOut()
 /** Vergrert die Ansicht */
 void ScribusView::slotZoomIn2()
 {
-	Doc->Scale += float(Doc->MagStep)/100;
-	if (Doc->Scale > float(Doc->MagMax)/100)
-		{
-		Doc->Scale = float(Doc->MagMax)/100;
-		}
+	Doc->Scale += static_cast<float>(Doc->MagStep)/100;
+	if (Doc->Scale > static_cast<float>(Doc->MagMax)/100)
+		Doc->Scale = static_cast<float>(Doc->MagMax)/100;
 	slotDoZoom();
 }
 
 /** Verkleinert die Ansicht */
 void ScribusView::slotZoomOut2()
 {
-	Doc->Scale -= float(Doc->MagStep)/100;
-	if (Doc->Scale < float(Doc->MagMin)/100)
-		{
-		Doc->Scale = float(Doc->MagMin)/100;
-		}
+	Doc->Scale -= static_cast<float>(Doc->MagStep)/100;
+	if (Doc->Scale < static_cast<float>(Doc->MagMin)/100)
+		Doc->Scale = static_cast<float>(Doc->MagMin)/100;
 	slotDoZoom();
 }
 
@@ -600,7 +590,7 @@ void ScribusView::DrawNew()
 			Pages.at(a)->update();
 			}
 		}
-	HR->repX = FALSE;
+	HR->repX = false;
 	HR->repaint();
 	VR->repaint();
 	Doc->ActPage = b;
@@ -632,6 +622,8 @@ void ScribusView::RecalcPictures(ProfilesL *Pr, QProgressBar *dia)
 			for (i=0; i < Pages.at(a)->Items.count(); i++)
 				{
 				it = Pages.at(a)->Items.at(i);
+				if (it->GrType != 0)
+					Pages.at(a)->UpdateGradient(it);
 				if ((it->PType == 2) && (it->PicAvail))
 					{
 					if (Pr->contains(it->IProfile))
@@ -641,6 +633,9 @@ void ScribusView::RecalcPictures(ProfilesL *Pr, QProgressBar *dia)
 						it->IProfile = Doc->CMSSettings.DefaultInputProfile;
 						Pages.at(a)->LoadPict(it->Pfile, i);
 						}
+					it->Sizing = true;
+					Pages.at(a)->AdjustPreview(it);
+					it->Sizing = false;
 					}
 				counter++;
 				if (dia != NULL)
@@ -675,7 +670,7 @@ void ScribusView::HideTemplate()
 {
 	for (uint a=0; a<Pages.count(); a++)
 		{
-		Pages.at(a)->Deselect();
+		Pages.at(a)->Deselect(true);
 		Pages.at(a)->parentWidget()->hide();
 		}
 	MasterPages = Pages;
@@ -695,7 +690,7 @@ void ScribusView::HideTemplate()
 
 QPixmap ScribusView::MPageToPixmap(QString name, int maxGr)
 {
-	QPixmap pm = QPixmap(Doc->PageB, Doc->PageH);
+	QPixmap pm = QPixmap(static_cast<int>(Doc->PageB), static_cast<int>(Doc->PageH));
 	pm.fill();
 	float sca = Doc->Scale;
 	bool frs = Doc->ShFrames;
@@ -734,7 +729,7 @@ QPixmap ScribusView::MPageToPixmap(QString name, int maxGr)
 					bb = b->BackBox;
 					b->NextBox = 0;
 					b->BackBox = 0;
-					b->paintObj(QRect(QRect(0, 0, Doc->PageB, Doc->PageH)), &pm);
+					b->paintObj(QRect(QRect(0, 0, static_cast<int>(Doc->PageB), static_cast<int>(Doc->PageH))), &pm);
 					b->toPixmap = false;
 					b->NextBox = nb;
 					b->BackBox = bb;
@@ -749,12 +744,12 @@ QPixmap ScribusView::MPageToPixmap(QString name, int maxGr)
 	Doc->Scale = sca;
 	QImage im2;
 	QImage im = pm.convertToImage();
-	float sx = im.width() / float(maxGr);
-	float sy = im.height() / float(maxGr);
+	float sx = im.width() / static_cast<float>(maxGr);
+	float sy = im.height() / static_cast<float>(maxGr);
 	if (sy < sx)
-		im2 = im.smoothScale(im.width() / sx, im.height() / sx);
+		im2 = im.smoothScale(static_cast<int>(im.width() / sx), static_cast<int>(im.height() / sx));
 	else
-		im2 = im.smoothScale(im.width() / sy, im.height() / sy);
+		im2 = im.smoothScale(static_cast<int>(im.width() / sy), static_cast<int>(im.height() / sy));
 	pm.convertFromImage(im2);
 	QPainter p;
 	p.begin(&pm);
@@ -768,7 +763,7 @@ QPixmap ScribusView::MPageToPixmap(QString name, int maxGr)
 
 QPixmap ScribusView::PageToPixmap(int Nr, int maxGr)
 {
-	QPixmap pm = QPixmap(Doc->PageB, Doc->PageH);
+	QPixmap pm = QPixmap(static_cast<int>(Doc->PageB), static_cast<int>(Doc->PageH));
 	pm.fill();
 	float sca = Doc->Scale;
 	bool frs = Doc->ShFrames;
@@ -809,7 +804,7 @@ QPixmap ScribusView::PageToPixmap(int Nr, int maxGr)
 						bb = b->BackBox;
 						b->NextBox = 0;
 						b->BackBox = 0;
-						b->paintObj(QRect(QRect(0, 0, Doc->PageB, Doc->PageH)), &pm);
+						b->paintObj(QRect(QRect(0, 0, static_cast<int>(Doc->PageB), static_cast<int>(Doc->PageH))), &pm);
 						b->toPixmap = false;
 						b->NextBox = nb;
 						b->BackBox = bb;
@@ -854,12 +849,12 @@ QPixmap ScribusView::PageToPixmap(int Nr, int maxGr)
 	Doc->Scale = sca;
 	QImage im2;
 	QImage im = pm.convertToImage();
-	float sx = im.width() / float(maxGr);
-	float sy = im.height() / float(maxGr);
+	float sx = im.width() / static_cast<float>(maxGr);
+	float sy = im.height() / static_cast<float>(maxGr);
 	if (sy < sx)
-		im2 = im.smoothScale(im.width() / sx, im.height() / sx);
+		im2 = im.smoothScale(static_cast<int>(im.width() / sx), static_cast<int>(im.height() / sx));
 	else
-		im2 = im.smoothScale(im.width() / sy, im.height() / sy);
+		im2 = im.smoothScale(static_cast<int>(im.width() / sy), static_cast<int>(im.height() / sy));
 	pm.convertFromImage(im2);
 	QPainter p;
 	p.begin(&pm);
@@ -871,7 +866,7 @@ QPixmap ScribusView::PageToPixmap(int Nr, int maxGr)
 	return pm;
 }
 
-QString ScribusView::CreatePS(PSLib *p, uint von, uint bis, int step, bool sep, QString SepNam, bool farb)
+void ScribusView::CreatePS(PSLib *p, uint von, uint bis, int step, bool sep, QString SepNam, bool farb, bool Hm, bool Vm)
 {
 	uint a;
 	int sepac;
@@ -879,11 +874,40 @@ QString ScribusView::CreatePS(PSLib *p, uint von, uint bis, int step, bool sep,
 	p->PS_set_Info("Title", Doc->DocTitel);
 	if (!farb)
 		p->PS_setGray();
+	p->PS_begin_doc(Doc->PageOri, Doc->PageB, Doc->PageH, abs(bis-von));
 	a = von;
 	sepac = 0;
+	for (uint ap = 0; ap < MasterPages.count(); ++ap)
+		{
+		if (MasterPages.at(ap)->Items.count() != 0)
+			{
+			if ((!sep) && (farb))
+				{
+				for (uint api = 0; api < MasterPages.at(ap)->Items.count(); ++api)
+					{
+					PageItem *it = MasterPages.at(ap)->Items.at(api);
+					if ((it->PType == 2) && (it->PicAvail) && (it->Pfile != "") && (it->isPrintable))
+						p->PS_ImageData(it->Pfile, it->AnName);
+					}
+				} 
+			p->PS_TemplateStart(MasterPages.at(ap)->PageNam, Doc->PageB, Doc->PageH);
+			ProcessPage(p, MasterPages.at(ap), ap+1, sep, farb);
+			p->PS_TemplateEnd();
+			}
+		}
 	while (a != bis)
 		{
-		p->PS_begin_page(Doc->PageOri, Doc->PageB, Doc->PageH, &Pages.at(a)->Margins);
+		p->PS_begin_page(Doc->PageB, Doc->PageH, &Pages.at(a)->Margins);
+		if (Hm)
+			{
+			p->PS_translate(Doc->PageB, 0);
+			p->PS_scale(-1, 1);
+			}
+		if (Vm)
+			{
+			p->PS_translate(0, Doc->PageH);
+			p->PS_scale(1, -1);
+			}
 		if (sep)
 			{
 			if (SepNam == "Black")
@@ -898,8 +922,207 @@ QString ScribusView::CreatePS(PSLib *p, uint von, uint bis, int step, bool sep,
 				p->PS_plate(sepac);
 			}
 		if (Pages.at(a)->MPageNam != "")
-			ProcessPage(p, MasterPages.at(MasterNames[Pages.at(a)->MPageNam]), a+1);
-		ProcessPage(p, Pages.at(a), a+1);
+			{
+			int h, s, v, k, tsz;
+			QCString chxc;
+			QString chx;
+			struct Pti *hl;
+			int Lnr = 0;
+			struct Layer ll;
+			ll.Drucken = false;
+			ll.LNr = 0;
+			Page* mPage = MasterPages.at(MasterNames[Pages.at(a)->MPageNam]);
+			if (mPage->Items.count() != 0)
+				{
+				p->PS_UseTemplate(Pages.at(a)->MPageNam);
+				for (uint lam = 0; lam < Doc->Layers.count(); ++lam)
+					{
+					Level2Layer(Doc, &ll, Lnr);
+					if (ll.Drucken)
+						{
+						for (uint am = 0; am < mPage->Items.count(); ++am)
+							{
+							PageItem *ite = mPage->Items.at(am);
+							if ((ite->LayerNr != ll.LNr) || (!ite->isPrintable))
+								continue;
+							if ((ite->PType == 2) && ((sep) || (!farb)))
+								{
+								p->PS_save();
+								p->PS_translate(ite->Xpos, Doc->PageH - ite->Ypos);
+								if (ite->Rot != 0)
+									p->PS_rotate(-ite->Rot);
+								if (ite->Pcolor != "None")
+									{
+									SetFarbe(ite->Pcolor, ite->Shade, &h, &s, &v, &k);
+									p->PS_setcmykcolor_fill(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+									if ((ite->FrameType == 2) && (!ite->ClipEdited))
+										p->PS_RoundRect(0, 0, ite->Width, -ite->Height, ite->RadRect);
+									else
+										SetClipPath(p, ite);
+									p->PS_closepath();
+									p->PS_fill();
+									}
+								else
+									p->PS_setcmykcolor_dummy();
+								if ((ite->FrameType == 2) && (!ite->ClipEdited))
+									p->PS_RoundRect(0, 0, ite->Width, -ite->Height, ite->RadRect);
+								else
+									SetClipPath(p, ite);
+								p->PS_closepath();
+								p->PS_clip();
+								if ((ite->flippedH % 2) != 0)
+									{
+									p->PS_translate(ite->Width, 0);
+									p->PS_scale(-1, 1);
+									}
+								if ((ite->flippedV % 2) != 0)
+									{
+									p->PS_translate(0, -ite->Height);
+									p->PS_scale(1, -1);
+									}
+								if ((ite->PicAvail) && (ite->Pfile != ""))
+									{
+									p->PS_translate(0, -ite->BBoxH*ite->LocalScY);
+									p->PS_image(-ite->BBoxX+ite->LocalX, -ite->LocalY, ite->Pfile, ite->LocalScX, ite->LocalScY);
+									}
+								p->PS_restore();
+								}
+							if (ite->PType == 4)
+								{
+								p->PS_save();
+								if (ite->Pcolor != "None")
+									{
+									SetFarbe(ite->Pcolor, ite->Shade, &h, &s, &v, &k);
+									p->PS_setcmykcolor_fill(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+									}
+								p->PS_translate(ite->Xpos, Doc->PageH - ite->Ypos);
+								if (ite->Rot != 0) 
+									p->PS_rotate(-ite->Rot);
+								if ((ite->Pcolor != "None") || (ite->GrType != 0))
+									{
+									if ((ite->FrameType == 2) && (!ite->ClipEdited))
+										p->PS_RoundRect(0, 0, ite->Width, -ite->Height, ite->RadRect);
+									else
+										SetClipPath(p, ite);
+									p->PS_closepath();
+									if (ite->GrType != 0)
+										{
+										SetFarbe(ite->GrColor2, ite->GrShade2, &h, &s, &v, &k);
+										p->PS_GradientCol1(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+										SetFarbe(ite->GrColor, ite->GrShade, &h, &s, &v, &k);
+										p->PS_GradientCol2(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+										switch (ite->GrType)
+											{
+											case 1:
+											case 2:
+											case 3:
+											case 4:
+												p->PS_LinGradient(ite->Width, -ite->Height, ite->PType, ite->GrType);
+												break;
+											case 5:
+												p->PS_RadGradient(ite->Width, -ite->Height, ite->PType);
+												break;
+											default:
+												break;
+											}
+										}
+									else
+										p->PS_fill();
+									}
+								if ((ite->flippedH % 2) != 0)
+									{
+									p->PS_translate(ite->Width, 0);
+									p->PS_scale(-1, 1);
+									}
+								if ((ite->flippedV % 2) != 0)
+									{
+									p->PS_translate(0, -ite->Height);
+									p->PS_scale(1, -1);
+									}
+								for (uint d = 0; d < ite->MaxChars; ++d)
+									{
+									hl = ite->Ptext.at(d);
+									if ((hl->ch == QChar(13)) || (hl->ch == QChar(10))) // || (hl->ch == QChar(32)))
+										continue;
+									if (hl->yp == 0)
+										break;
+									tsz = hl->csize;
+									chx = hl->ch;
+									if (hl->ch == QChar(30))
+										{
+										if (Doc->MasterP)
+											chx = "#";
+										else
+											{
+											uint zae = 0;
+											while (ite->Ptext.at(d+zae)->ch == QChar(30))
+												{
+												zae++;
+												if (d+zae == ite->MaxChars)
+													break;
+												}
+											QString out="%1";
+											chx = out.arg(a+Doc->FirstPnum, zae).right(zae).left(1);
+											}
+										}
+									if ((hl->cstyle & 127) == 0)
+										p->PS_selectfont(hl->cfont, hl->csize);
+									if (hl->cstyle & 64)
+										{
+										if (chx.upper() != chx)
+											{
+											tsz = hl->csize * Doc->VKapit / 100;
+											chx = chx.upper();
+											}
+										}
+									if (hl->cstyle & 1)
+										tsz = hl->csize * Doc->VHochSc / 100;
+									if (hl->cstyle & 2)
+										tsz = hl->csize * Doc->VHochSc / 100;
+									if (hl->cstyle & 4)
+										p->PS_selectfontItalic(hl->cfont, tsz);
+									else
+										{
+										if ((hl->cstyle & 127) != 0)
+											p->PS_selectfont(hl->cfont, tsz);
+										}
+									if (hl->ccolor != "None")
+										{
+										SetFarbe(hl->ccolor, hl->cshade, &h, &s, &v, &k);
+										p->PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+										}
+									if ((chx == "(") || (chx == ")") || (chx == "\\"))
+										chx.prepend("\\");
+							  	chxc = chx.local8Bit();
+									if (hl->cstyle & 32)
+										p->PS_show_xyBold(chxc, hl->xp, -hl->yp);
+									else
+										p->PS_show_xy(chxc, hl->xp, -hl->yp);
+									if (hl->cstyle & 8)
+										p->PS_underline(chxc, hl->xp, -hl->yp);
+									if (hl->cstyle & 16)
+										p->PS_strikeout(chxc, hl->xp, -hl->yp + tsz / 3);
+									if ((hl->cstyle & 128) && ((ite->Ptext.at(QMIN(d+1, ite->Ptext.count()-1))->yp != hl->yp) && (ite->Ptext.at(QMIN(d+1, ite->Ptext.count()-1))->ch != QChar(13))))
+										{
+										QPainter ph;
+										QFont ffo;
+										ph.begin(this);
+										int chs = hl->csize;
+										ite->SetZeichAttr(&ph, &ffo, hl, &chs, &chx);
+										float wide = Cwidth(Doc, &ph, hl->cfont, chx, chs);
+										p->PS_show(hl->xp+wide, -hl->yp);
+										ph.end();
+										}
+									}
+								p->PS_restore();
+								}
+							}
+						}
+					Lnr++;
+					}
+				}
+			}
+		ProcessPage(p, Pages.at(a), a+1, sep, farb);
 		p->PS_end_page();
 		if (sep)
 			{
@@ -919,10 +1142,10 @@ QString ScribusView::CreatePS(PSLib *p, uint von, uint bis, int step, bool sep,
 		else
 			a += step;
 		}
-	return p->PS_close();
+	p->PS_close();
 }
 
-void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr)
+void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr, bool sep, bool farb)
 {
 	uint b, d;
 	int h, s, v, k, tsz;
@@ -935,16 +1158,20 @@ void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr)
 	struct Layer ll;
 	ll.Drucken = false;
 	ll.LNr = 0;
-	for (uint la = 0; la < Doc->Layers.count(); la++)
+	for (uint la = 0; la < Doc->Layers.count(); ++la)
 		{
 		Level2Layer(Doc, &ll, Lnr);
 		if (ll.Drucken)
 			{
-			for (b = 0; b < a->Items.count(); b++)
+			for (b = 0; b < a->Items.count(); ++b)
 				{
 				c = a->Items.at(b);
 				if (c->LayerNr != ll.LNr)
 					continue;
+				if ((a->PageNam != "") && (c->PType == 4))
+					continue;
+				if ((a->PageNam != "") && (c->PType == 2) && ((sep) || (!farb)))
+					continue;
 				if (c->isPrintable)
 					{
 					p->PS_save();
@@ -962,9 +1189,7 @@ void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr)
 					p->PS_setdash(c->PLineArt, c->PLineEnd, c->PLineJoin);
 					p->PS_translate(c->Xpos, Doc->PageH - c->Ypos);
 					if (c->Rot != 0)
-						{
 						p->PS_rotate(-c->Rot);
-						}
 					switch (c->PType)
 						{
 						case 1:
@@ -1001,24 +1226,20 @@ void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr)
 							if ((c->PicAvail) && (c->Pfile != ""))
 								{
 								p->PS_translate(0, -c->BBoxH*c->LocalScY);
-								p->PS_image(-c->BBoxX+c->LocalX, -c->LocalY, c->Pfile, c->LocalScX, c->LocalScY);
+								if (a->PageNam != "")
+									p->PS_image(-c->BBoxX+c->LocalX, -c->LocalY, c->Pfile, c->LocalScX, c->LocalScY, c->AnName);
+								else
+									p->PS_image(-c->BBoxX+c->LocalX, -c->LocalY, c->Pfile, c->LocalScX, c->LocalScY);
 								}						
 							needsStroke = false;
 							break;
-						case 3:
-							if (c->RadRect != 0)
-								p->PS_RoundRect(0, 0, c->Width, -c->Height, c->RadRect);
-							else
-								p->PS_rect(0, 0, c->Width, -c->Height);
-							needsStroke = true;
-							break;
 						case 4:
 							needsStroke = false;
 							if (c->isBookmark)
 								{
 								QString bm = "";
 								QString cc;
-								for (d = 0; d < c->Ptext.count(); d++)
+								for (d = 0; d < c->Ptext.count(); ++d)
 									{
 									if ((c->Ptext.at(d)->ch == QChar(13)) || (c->Ptext.at(d)->ch == QChar(10)))
 										break;
@@ -1030,21 +1251,43 @@ void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr)
 								{
 								QString bm = "";
 								QString cc;
-								for (d = 0; d < c->Ptext.count(); d++)
+								for (d = 0; d < c->Ptext.count(); ++d)
 									{
 									bm += "\\"+cc.setNum(c->Ptext.at(d)->ch.at(0).unicode(), 8);
 									}
 								p->PDF_Annotation(bm, 0, 0, c->Width, -c->Height);
 								break;
 								}
-							if (c->Pcolor != "None")
+							if ((c->Pcolor != "None") || (c->GrType != 0))
 								{
 								if ((c->FrameType == 2) && (!c->ClipEdited))
 									p->PS_RoundRect(0, 0, c->Width, -c->Height, c->RadRect);
 								else
 									SetClipPath(p, c);
 								p->PS_closepath();
-								p->PS_fill();
+								if ((c->GrType != 0) && (a->PageNam == ""))
+									{
+									SetFarbe(c->GrColor2, c->GrShade2, &h, &s, &v, &k);
+									p->PS_GradientCol1(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+									SetFarbe(c->GrColor, c->GrShade, &h, &s, &v, &k);
+									p->PS_GradientCol2(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+									switch (c->GrType)
+										{
+										case 1:
+										case 2:
+										case 3:
+										case 4:
+											p->PS_LinGradient(c->Width, -c->Height, c->PType, c->GrType);
+											break;
+										case 5:
+											p->PS_RadGradient(c->Width, -c->Height, c->PType);
+											break;
+										default:
+											break;
+										}
+									}
+								else
+									p->PS_fill();
 								}
 							if ((c->flippedH % 2) != 0)
 								{
@@ -1056,7 +1299,7 @@ void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr)
 								p->PS_translate(0, -c->Height);
 								p->PS_scale(1, -1);
 								}
-							for (d = 0; d < c->MaxChars; d++)
+							for (d = 0; d < c->MaxChars; ++d)
 								{
 								hl = c->Ptext.at(d);
 								if ((hl->ch == QChar(13)) || (hl->ch == QChar(10))) // || (hl->ch == QChar(32)))
@@ -1119,8 +1362,17 @@ void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr)
 									p->PS_underline(chxc, hl->xp, -hl->yp);
 								if (hl->cstyle & 16)
 									p->PS_strikeout(chxc, hl->xp, -hl->yp + tsz / 3);
-								if ((hl->cstyle & 128) && (c->Ptext.at(QMIN(d+1, c->Ptext.count()-1))->yp != hl->yp))
-									p->PS_show();
+								if ((hl->cstyle & 128) && ((c->Ptext.at(QMIN(d+1, c->Ptext.count()-1))->yp != hl->yp) && (c->Ptext.at(QMIN(d+1, c->Ptext.count()-1))->ch != QChar(13))))
+									{
+									QPainter ph;
+									QFont ffo;
+									ph.begin(this);
+									int chs = hl->csize;
+									c->SetZeichAttr(&ph, &ffo, hl, &chs, &chx);
+									float wide = Cwidth(Doc, &ph, hl->cfont, chx, chs);
+									p->PS_show(hl->xp+wide, -hl->yp);
+									ph.end();
+									}
 								}
 							break;
 						case 5:
@@ -1129,6 +1381,7 @@ void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr)
 							p->PS_stroke();
 							needsStroke = false;
 							break;
+						case 3:
 						case 6:
 							SetClipPath(p, c);
 							p->PS_closepath();
@@ -1151,7 +1404,7 @@ void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr)
 									}
 								}
 							needsStroke = false;
-							for (d = 0; d < c->MaxChars; d++)
+							for (d = 0; d < c->MaxChars; ++d)
 								{
 								hl = c->Ptext.at(d);
 								if ((hl->ch == QChar(13)) || (hl->ch == QChar(30))) // || (hl->ch == QChar(32)))
@@ -1198,22 +1451,53 @@ void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr)
 									p->PS_underline(chxc, hl->xp, -hl->yp);
 								if (hl->cstyle & 16)
 									p->PS_strikeout(chxc, hl->xp, -hl->yp + tsz / 3);
-								if ((hl->cstyle & 128) && (c->Ptext.at(QMIN(d+1, c->Ptext.count()-1))->yp != hl->yp))
-									p->PS_show();
+/*								if ((hl->cstyle & 128) && (c->Ptext.at(QMIN(d+1, c->Ptext.count()-1))->yp != hl->yp))
+									p->PS_show();  */
 								p->PS_restore();
 								}
 							break;
 						}
 					if (needsStroke)
 						{
-						if (c->Pcolor == "None")
-							p->PS_stroke();
+						if ((c->GrType != 0) && (a->PageNam == ""))
+							{
+							SetFarbe(c->GrColor2, c->GrShade2, &h, &s, &v, &k);
+							p->PS_GradientCol1(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+							SetFarbe(c->GrColor, c->GrShade, &h, &s, &v, &k);
+							p->PS_GradientCol2(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+							switch (c->GrType)
+								{
+								case 1:
+								case 2:
+								case 3:
+								case 4:
+									p->PS_LinGradient(c->Width, -c->Height, c->PType, c->GrType);
+									break;
+								case 5:
+									p->PS_RadGradient(c->Width, -c->Height, c->PType);
+									break;
+								default:
+									break;
+								}
+							if (c->Pcolor2 != "None")
+								p->PS_stroke();
+							}
 						else
 							{
-							if (c->Pcolor2 == "None")
-								p->PS_fill();
-							else
+							if ((c->Pcolor2 != "None") && (c->Pcolor != "None"))
 								p->PS_fill_stroke();
+							else
+								{
+								if ((c->Pcolor2 == "None") && (c->Pcolor == "None"))
+									p->PS_newpath();
+								else
+									{
+									if (c->Pcolor == "None")
+										p->PS_stroke();
+									if (c->Pcolor2 == "None")
+										p->PS_fill();
+									}
+								}
 							}
 						}
 					p->PS_restore();
@@ -1259,13 +1543,19 @@ void ScribusView::SetClipPath(PSLib *p, PageItem *c)
 
 void ScribusView::contentsWheelEvent(QWheelEvent *w)
 {
-	if (w->delta() < 0)
+	if (w->state() & ShiftButton)
 		{
-			scrollBy(0, Prefs->Wheelval);
+		if (w->delta() > 0)
+			slotZoomIn2();
+		else
+			slotZoomOut2();
 		}
 	else
 		{
-		  scrollBy(0, -Prefs->Wheelval);
+		if (w->delta() < 0)
+			scrollBy(0, Prefs->Wheelval);
+		else
+			scrollBy(0, -Prefs->Wheelval);
 		}
 	w->accept();
 }
