@@ -46,10 +46,12 @@ class ScribusView : public QScrollView
   Q_OBJECT
   public:
     ScribusView(QWidget *parent=0, ScribusDoc *doc=0, preV *prefs=0);
-    ~ScribusView();
+    ~ScribusView() {};
   /** Vergroesserungseingabefeld */
   QLineEdit *LE;
   QToolButton *UN;
+  Hruler *HR;
+  Vruler *VR;
   /** Liste der Seiten */
   QPtrList<Page> Pages;
   /** Liste der Musterseiten */
@@ -73,12 +75,13 @@ class ScribusView : public QScrollView
   QPixmap PageToPixmap(int Nr, int maxGr);
 	QPixmap MPageToPixmap(QString name, int maxGr);
   void RecalcPictures(ProfilesL *Pr, QProgressBar *dia = 0);
-  QString CreatePS(PSLib *p, uint von, uint bis, int step, bool sep, QString SepNam, bool farb);
-  void ProcessPage(PSLib *p, Page* a, uint PNr);
+  void CreatePS(PSLib *p, uint von, uint bis, int step, bool sep, QString SepNam, bool farb, bool Hm, bool Vm);
+  void ProcessPage(PSLib *p, Page* a, uint PNr, bool sep = false, bool farb = true);
 	void SetClipPath(PSLib *p, PageItem *c);
 	void SetFarbe(QString farb, int shade, int *h, int *s, int *v, int *k);
   /** Dokument zu dem die Seite gehrt */
   ScribusDoc *Doc;
+  preV *Prefs;
 
 public slots: // Public slots
   /** Fhrt die Vergrerung/Verkleinerung aus; */
@@ -109,10 +112,7 @@ private: // Private attributes
   QPopupMenu *Seitmen;
   QPopupMenu *Unitmen;
 	QPopupMenu *Laymen;
-  Hruler *HR;
-  Vruler *VR;
   bool Ready;
-  preV *Prefs;
 private slots:
   void Zval();
   void setRulerPos(int x, int y);
