@@ -27,16 +27,19 @@
 #include <qdom.h>
 #include <qimage.h>
 #include <qpointarray.h>
-#include <stdlib.h>
-#include <math.h>
+#include <cstdlib>
+#include <cmath>
+#include "md5.h"
 #include "config.h"
 #include "scribusdoc.h"
+#ifdef HAVE_LIBZ
+	#include <zlib.h>
+#endif
 #ifdef HAVE_TIFF
 	#include <tiffio.h>
 #endif
 #ifdef HAVE_CMS
 	#include <lcms.h>
-extern cmsHPROFILE CMSinputProf;
 extern cmsHPROFILE CMSoutputProf;
 extern cmsHPROFILE CMSprinterProf;
 extern cmsHTRANSFORM stdTrans;
@@ -50,8 +53,15 @@ extern int IntentMonitor;
 extern int IntentPrinter;
 #endif
 extern ProfilesL InputProfiles;
-// #include <iostream.h>
 
+QByteArray ComputeMD5Sum(QByteArray *in);
+char *toHex( uchar u );
+QString String2Hex(QString *in, bool lang = true);
+QString CompressStr(QString *in);
+QString ImageToTxt(QImage *im);
+QString ImageToCMYK(QImage *im);
+QString ImageToCMYK_PS(QImage *im, int pl);
+QString MaskToTxt(QImage *im, bool PDF = true);
 void Level2Layer(ScribusDoc *doc, struct Layer *ll, int Level);
 void BezierPoints(QPointArray *ar, QPoint n1, QPoint n2, QPoint n3, QPoint n4);
 float xy2Deg(float x, float y);
@@ -105,7 +115,7 @@ QImage ProofPict(QImage *Im, QString Prof, int Rend)
 															 				 CMSprinterProf,
 															 				 IntentPrinter,
 															 				 Rend, dcmsFlags);
-		for (int i=0; i < out.height(); i++)
+		for (int i=0; i < out.height(); ++i)
 			{
 			LPBYTE ptr = out.scanLine(i);
 			cmsDoTransform(xform, ptr, ptr, out.width());
@@ -131,7 +141,7 @@ QImage ProofPict(QImage *Im, QString Prof, int Rend)
 															 	 CMSoutputProf, TYPE_RGBA_8,
 															 	 Rend,
 															 	 0);
-			for (int i=0; i < out.height(); i++)
+			for (int i=0; i < out.height(); ++i)
 				{
 				LPBYTE ptr = out.scanLine(i);
 				cmsDoTransform(xform, ptr, ptr, out.width());
@@ -153,7 +163,7 @@ QImage ProofImage(QImage *Im)
 	QImage out = Im->copy();
 	if ((CMSuse) && (SoftProofing))
 		{
-		for (int i=0; i < out.height(); i++)
+		for (int i=0; i < out.height(); ++i)
 			{
 			LPBYTE ptr = out.scanLine(i);
 			cmsDoTransform(stdProofImg, ptr, ptr, out.width());
@@ -163,7 +173,7 @@ QImage ProofImage(QImage *Im)
 		{
 		if (CMSuse)
 			{
-			for (int i=0; i < out.height(); i++)
+			for (int i=0; i < out.height(); ++i)
 				{
 				LPBYTE ptr = out.scanLine(i);
 				cmsDoTransform(stdTransImg, ptr, ptr, out.width());
@@ -228,38 +238,41 @@ QImage LoadPict(QString fn)
 					int hi = image.height();
 					QBitmap bm("/tmp/sc.png");
 					bm.fill(Qt::color1);
-    			int i = 0;
     			QPainter pp;
     			pp.begin(&bm);
     			pp.setPen(Qt::color0);
     			QString tmp2;
-    			if ( image.depth() == 8 ) {
-        			for( int yi=0; yi < hi; yi++ ) {
-            			uchar * s = image.scanLine( yi );
-            			for( int xi=0; xi < wi; xi++ ) {
-                			if(image.color(s[xi]) == 0xffffffff)
-                				pp.drawPoint(xi, yi);
-                			i++;
-            			}
+    			if ( image.depth() == 8 )
+						{
+        		for( int yi=0; yi < hi; ++yi )
+							{
+            	uchar * s = image.scanLine( yi );
+            	for( int xi=0; xi < wi; ++xi )
+								{
+                if(image.color(s[xi]) == 0xffffffff)
+                	pp.drawPoint(xi, yi);
+            		}
         			}
-    			} else {
-        			for( int yi=0; yi < hi; yi++ ) {
-            			QRgb * s = (QRgb*)(image.scanLine( yi ));
-            			for( int xi=0; xi < wi; xi++ )
-                			for( xi=0; xi < wi; xi++ ) {
-                					if((*s++) == 0xffffffff)
-                							pp.drawPoint(xi, yi);
-                    			i++;
-                			}
+    				}
+					else
+						{
+        		for( int yi=0; yi < hi; ++yi )
+							{
+            	QRgb * s = (QRgb*)(image.scanLine( yi ));
+              for(int xi=0; xi < wi; ++xi )
+								{
+                if((*s++) == 0xffffffff)
+                	pp.drawPoint(xi, yi);
+                }
         			}
-    			}
+    				}
     			pp.end();
 					QPixmap pm;
 					pm.convertFromImage(image);
 					pm.setMask(bm);
 					im4.setAlphaBuffer(true);
 					im4 = pm.convertToImage();
-					Bild = im4.copy(x, 0, b-x, h-y);
+					Bild = im4.copy(static_cast<int>(x), 0, static_cast<int>(b-x), static_cast<int>(h-y));
 					system("rm -f /tmp/sc.png");
 					}
 				}
@@ -287,16 +300,16 @@ QImage LoadPict(QString fn)
 						 TIFFGetG(0x1234567)==qGreen(0x1234567) &&
 						 TIFFGetB(0x1234567)==qBlue (0x1234567))
 						{
-						for(unsigned y=0; y<height; y++)
+						for(unsigned y=0; y<height; ++y)
 							memcpy(img.scanLine(height-1-y),bits+y*width,width*4);
 						}
 					else
 						{
 						uint32 *inp=bits;
-						for(unsigned y=0; y<height; y++)
+						for(unsigned y=0; y<height; ++y)
 							{
 							QRgb *row=(QRgb*) (img.scanLine(height-1-y));
-							for(unsigned x=0; x<width; x++)
+							for(unsigned x=0; x<width; ++x)
 								{
 								const uint32 col=*(inp++);
 								row[x]=qRgb(TIFFGetR(col), TIFFGetG(col), TIFFGetB(col) ) | (TIFFGetA(col)<<24);
@@ -347,7 +360,7 @@ float QStoFloat(QString in)
 QPixmap loadIcon(QString nam)
 {
   QString pfad = PREL;
-  pfad += "/share/scribus/icons/"+nam;
+  pfad += "/lib/scribus/icons/"+nam;
 	QPixmap pm;
 	pm.load(pfad);
 	return pm;
@@ -356,6 +369,9 @@ QPixmap loadIcon(QString nam)
 bool loadText(QString nam, QString *Buffer)
 {
 	QFile f(nam);
+	QFileInfo fi(f);
+	if (!fi.exists())
+		return false;
 	uint posi;
 	bool ret = false;
 	QByteArray bb(f.size());
@@ -363,7 +379,7 @@ bool loadText(QString nam, QString *Buffer)
 		{
 		f.readBlock(bb.data(), f.size());
 		f.close();
-		for (posi = 0; posi < bb.size(); posi++)
+		for (posi = 0; posi < bb.size(); ++posi)
 			{
 			*Buffer += bb[posi];
 			}
@@ -379,10 +395,14 @@ bool loadText(QString nam, QString *Buffer)
 bool loadTextQS(QString nam, QString *Buffer)
 {
 	QFile f(nam);
+	QFileInfo fi(f);
+	if (!fi.exists())
+		return false;
 	bool ret = false;
 	if (f.open(IO_ReadOnly))
 		{
 		QTextStream t(&f);
+		t.setEncoding(QTextStream::Locale);
 		*Buffer = t.read();
 		f.close();
 		ret = true;
@@ -415,7 +435,7 @@ QPointArray RegularPolygon(float w, float h, uint c, bool star, float factor, fl
 	int mx = 0;
 	int my = 0;
 	QPointArray pts = QPointArray();
-	for (uint x = 0; x < cx; x++)
+	for (uint x = 0; x < cx; ++x)
 		{
 		sc = seg * x + 180.0 + rota;
 		if (star)
@@ -455,7 +475,7 @@ FPointArray RegularPolygonF(float w, float h, uint c, bool star, float factor, f
 	float mx = 0;
 	float my = 0;
 	FPointArray pts = FPointArray();
-	for (uint x = 0; x < cx; x++)
+	for (uint x = 0; x < cx; ++x)
 		{
 		sc = seg * x + 180.0 + rota;
 		if (star)
@@ -516,7 +536,7 @@ void BezierPoints(QPointArray *ar, QPoint n1, QPoint n2, QPoint n3, QPoint n4)
 
 void Level2Layer(ScribusDoc *doc, struct Layer *ll, int Level)
 {
-	for (uint la2 = 0; la2 < doc->Layers.count(); la2++)
+	for (uint la2 = 0; la2 < doc->Layers.count(); ++la2)
 		{
 		if (doc->Layers[la2].Level == Level)
 			{
@@ -527,3 +547,175 @@ void Level2Layer(ScribusDoc *doc, struct Layer *ll, int Level)
 			}
 		}
 }
+
+QString ImageToTxt(QImage *im)
+{
+	int h = im->height();
+	int w = im->width();
+	QString ImgStr = "";
+	for( int yi=0; yi < h; ++yi )
+		{
+		QRgb * s = (QRgb*)(im->scanLine( yi ));
+		for( int xi=0; xi < w; ++xi )
+			{
+			QRgb r=*s++;
+			unsigned char u=qRed(r);
+			ImgStr += u;
+			u=qGreen(r);
+			ImgStr += u;
+			u=qBlue(r);
+			ImgStr += u;
+			}
+		}
+	return ImgStr;
+}
+
+QString ImageToCMYK(QImage *im)
+{
+	int h = im->height();
+	int w = im->width();
+	QString ImgStr = "";
+	for( int yi=0; yi < h; ++yi )
+		{
+		QRgb * s = (QRgb*)(im->scanLine( yi ));
+		for( int xi=0; xi < w; ++xi )
+			{
+			QRgb r=*s++;
+			int c = 255 - qRed(r);
+			int m = 255 - qGreen(r);
+			int y = 255 - qBlue(r);
+			int k = QMIN(QMIN(c, m), y);
+			ImgStr += c - k;
+			ImgStr += m - k;
+			ImgStr += y - k;
+			ImgStr += k;
+			}
+		}
+	return ImgStr;
+}
+
+QString ImageToCMYK_PS(QImage *im, int pl)
+{
+	int h = im->height();
+	int w = im->width();
+	QString ImgStr = "";
+	for( int yi=0; yi < h; ++yi )
+		{
+		QRgb * s = (QRgb*)(im->scanLine( yi ));
+		for( int xi=0; xi < w; ++xi )
+			{
+			QRgb r=*s++;
+			int c = 255 - qRed(r);
+			int m = 255 - qGreen(r);
+			int y = 255 - qBlue(r);
+			int k = QMIN(QMIN(c, m), y);
+			if (pl == -1)
+				{
+				ImgStr += c - k;
+				ImgStr += m - k;
+				ImgStr += y - k;
+				ImgStr += k;
+				}
+			else
+				{
+				if (pl == 1)
+					ImgStr += c - k;
+				if (pl == 2)
+					ImgStr += m - k;
+				if (pl == 3)
+					ImgStr += y - k;
+				if (pl == 0)
+					ImgStr += k;
+				}
+			}
+		}
+	return ImgStr;
+}
+
+QString MaskToTxt(QImage *im, bool PDF)
+{
+	int h = im->height();
+	int w = im->width();
+  int w2;
+  w2 = w / 8;
+  if ((w % 8) != 0)
+  	w2++;
+	QString ImgStr = "";
+	for( int yi=0; yi < h; ++yi )
+		{
+		uchar * s = im->scanLine( yi );
+		for( int xi=0; xi < w2; ++xi )
+			{
+			unsigned char u = *(s+xi);
+			if (PDF)
+				ImgStr += ~u;
+			else
+				ImgStr += u;
+			}
+		}
+	return ImgStr;
+}
+
+QString CompressStr(QString *in)
+{
+	QString out = "";
+#ifdef HAVE_LIBZ
+	QByteArray bb(in->length());
+	for (uint ax = 0; ax < in->length(); ++ax)
+		{
+		bb[ax] = uchar(QChar(in->at(ax)));
+		}
+	uLong exlen = uint(bb.size() * 0.001 + 16) + bb.size();
+	QByteArray bc(exlen);
+	compress2((Byte *)bc.data(), &exlen, (Byte *)bb.data(), uLong(bb.size()), 9);
+	for (uint cl = 0; cl < exlen; ++cl)
+		{
+		out += bc[cl];
+		}
+#else
+	out = *in;
+#endif
+	return out;
+}
+
+char *toHex( uchar u )
+{
+    static char hexVal[3];
+    int i = 1;
+    while ( i >= 0 )
+			{
+			ushort hex = (u & 0x000f);
+			if ( hex < 0x0a )
+	    	hexVal[i] = '0'+hex;
+			else
+	    	hexVal[i] = 'A'+(hex-0x0a);
+			u = u >> 4;
+			i--;
+    	}
+    hexVal[2] = '\0';
+    return hexVal;
+}
+
+QString String2Hex(QString *in, bool lang)
+{
+	int i = 0;
+	QString out = "";
+	for( uint xi = 0; xi < in->length(); ++xi )
+		{
+		out += toHex(uchar(QChar(in->at(xi))));
+		++i;
+		if ((i>40) && (lang))
+			{
+			out += '\n';
+			i=0;
+			}
+		}
+	return out;
+}
+
+QByteArray ComputeMD5Sum(QByteArray *in)
+{
+	QByteArray MDsum(16);
+	md5_buffer (in->data(), in->size(), (void*)MDsum.data());
+	return MDsum;
+}
