@@ -17,6 +17,8 @@
 
 #include "vruler.h"
 #include "vruler.moc"
+#include "page.h"
+#include <qcursor.h>
 Vruler::Vruler(QScrollView *pa, ScribusDoc *doc) : QWidget(pa)
 {
 	setEraseColor(QColor(255,255,255));
@@ -26,9 +28,27 @@ Vruler::Vruler(QScrollView *pa, ScribusDoc *doc) : QWidget(pa)
 	offs = -12;
 	Markp = 0;
 	oldMark = 0;
+	Mpressed = false;
 }
 
-Vruler::~Vruler(){
+void Vruler::mousePressEvent(QMouseEvent *)
+{
+	Mpressed = true;
+	qApp->setOverrideCursor(QCursor(SplitVCursor), true);
+}
+
+void Vruler::mouseReleaseEvent(QMouseEvent *m)
+{
+	Mpressed = false;
+	doku->ActPage->DrVX = -1;
+	doku->ActPage->SetXGuide(m);
+	qApp->setOverrideCursor(QCursor(ArrowCursor), true);
+}
+
+void Vruler::mouseMoveEvent(QMouseEvent *m)
+{
+	if ((Mpressed) && (m->pos().x() > width()))
+		doku->ActPage->FromVRuler(m);
 }
 
 void Vruler::paintEvent(QPaintEvent *)
@@ -82,28 +102,28 @@ void Vruler::paintEvent(QPaintEvent *)
 		}
 	else
 		pc = doku->PageC;
-	for (xx = 0; xx < pc; xx++)
+	for (xx = 0; xx < pc; ++xx)
 		{
 		of = xx * (doku->PageH+30.0);
 		for (xl = 0; xl < doku->PageH; xl += iter)
 			{
-			p.drawLine(18, xl+of, 24, xl+of);
+			p.drawLine(18, static_cast<int>(xl+of), 24, static_cast<int>(xl+of));
 			}
 		for (xl = 0; xl < doku->PageH+(iter2/2); xl += iter2)
 			{
-			p.drawLine(11, xl+of, 24, xl+of);
+			p.drawLine(11, static_cast<int>(xl+of), 24, static_cast<int>(xl+of));
 			p.save();
 			p.scale(1.0, 1.0 / sc);
 			switch (doku->Einheit)
 				{
 				case 2:
-					p.drawText(9, (xl+of+qRound(10/sc)) * sc, QString::number(xl / iter2));
+					p.drawText(9, static_cast<int>((xl+of+qRound(10/sc)) * sc), QString::number(xl / iter2));
 					break;
 				case 3:
-					p.drawText(9, (xl+of+qRound(10/sc)) * sc, QString::number(xl / iter));
+					p.drawText(9, static_cast<int>((xl+of+qRound(10/sc)) * sc), QString::number(xl / iter));
 					break;
 				default:
-					p.drawText(9, (xl+of+qRound(10/sc)) * sc, QString::number(xl / iter * 10));
+					p.drawText(9, static_cast<int>((xl+of+qRound(10/sc)) * sc), QString::number(xl / iter * 10));
 					break;
 				}
 			p.restore();
